@@ -2,6 +2,7 @@ package org.eclipse.swt.tools.internal;
 
 import java.io.*;
 import java.util.*;
+import java.util.Map.*;
 
 import org.eclipse.jdt.core.dom.*;
 import org.eclipse.jface.text.*;
@@ -9,7 +10,7 @@ import org.eclipse.jface.text.*;
 /**
  * Bashes the javadoc from one source tree into another. Only produces new
  * source files for compilation units that have changed.
- * 
+ *
  * How to use: 1) make sure you have the latest org.eclipse.swt (master branch)
  * in your workspace, and that you have no outstanding org.eclipse.swt changes
  * 2) create a Bugzilla bug called
@@ -30,7 +31,7 @@ import org.eclipse.jface.text.*;
  * before a javadoc comment) 10) use the Bugzilla bug as the commit comment for
  * javadoc and copyright bash commits 11) make a version of the org.eclipse.swt
  * project after bashing (use tag name AFTER_...)
- * 
+ *
  * 12) Copyright bash (tag before and after): NOTE: JavadocBasher does not fix
  * copyrights. Use the "Fix Copyrights" tool in org.eclipse.releng.tools for
  * that (always fix copyrights after bash). Use Help->Install New Software... to
@@ -52,7 +53,7 @@ import org.eclipse.jface.text.*;
  * internal/mozilla have 2 copyright lines and the tool tries to change the 1st
  * - don't keep the 1st change (Netscape 1998-2015), but update the 2nd (IBM)
  * manually.
- * 
+ *
  * NOTE: JavadocBasher now does a fairly good job of checking API consistency.
  * We used to use org.eclipse.swt.diff for API consistency checking, but it was
  * difficult to maintain.
@@ -90,7 +91,6 @@ public class JavadocBasher {
 				"Eclipse SWT Browser",
 				// "Eclipse SWT Custom Widgets",
 				"Eclipse SWT Drag and Drop", "Eclipse SWT Effects",
-				"Eclipse SWT Mozilla",
 				// "Eclipse SWT OLE Win32",
 				"Eclipse SWT OpenGL",
 				// "Eclipse SWT PI",
@@ -99,7 +99,6 @@ public class JavadocBasher {
 		String sourceSubdir = "win32";
 		String[] targetSubdirs = new String[] { "cairo", // used by gtk
 				// "carbon", // we are no longer maintaining carbon
-				"cde", // used by gtk
 				"cocoa",
 				// "common",
 				// "common_j2me",
@@ -109,11 +108,8 @@ public class JavadocBasher {
 				"emulated/expand", // used by carbon, cocoa
 				"emulated/taskbar", // used by carbon, gtk
 				"emulated/tooltip", // used by cocoa (?!)
-				"gnome", // used by gtk
 				"glx", // used by gtk
-				"gtk",
-				"mozilla", // used by carbon, cocoa, gtk, win32
-		// "qt", // folder should be deleted
+				"gtk"
 		};
 
 		System.out.println("==== Start Bashing ====");
@@ -152,9 +148,8 @@ public class JavadocBasher {
 				+ ((count == 1) ? " file" : " files") + " in " + targetSubdir
 				+ ((count > 0) ? ":" : "."));
 		if (count > 0) {
-			Iterator<String> i = list.iterator();
-			while (i.hasNext())
-				System.out.println(label + ": " + i.next());
+			for(String s : list)
+				System.out.println(label + ": " + s);
 			System.out.println();
 		}
 	}
@@ -422,14 +417,14 @@ public class JavadocBasher {
 				"Display.getSystemFont",
 				"Display.msg",
 				"Menu.handle",
-				"Shell.win32_newDisplaylong",	
+				"Shell.win32_newDisplaylong",
 				"Accessible.internal_WM_GETOBJECTlonglong",
 				"TransferData.result",
 				"TransferData.stgmedium",
 				"TransferData.pIDataObject",
 				"TransferData.formatetc",
 				"Printer.handle",
-				"Printer.checkDevice",	
+				"Printer.checkDevice",
 				"TableDragSourceEffect.dragFinishedDragSourceEvent",
 				"TableDragSourceEffect.dragStartDragSourceEvent",
 				"TableDropTargetEffect.dragOverDropTargetEvent",
@@ -453,9 +448,9 @@ public class JavadocBasher {
 				"Display.getClientArea",
 				"TreeItem.handle",
 			};
-			for (Iterator<String> iterator = comments.keySet().iterator(); iterator.hasNext();) {
-				String name = iterator.next();
-				if (comments.get(name).length() > 0){
+			for (Entry<String, String> entry: comments.entrySet()) {
+				String name = entry.getKey();
+				if (entry.getValue().length() > 0){
 					int i = 0;
 					for (i = 0; i < filter.length; i++) {
 						if (name.equals(filter[i])) break;
