@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -393,22 +396,14 @@ public DropTarget(Control control, int style) {
 
 	control.setData(DND.DROP_TARGET_KEY, this);
 
-	controlListener = new Listener () {
-		@Override
-		public void handleEvent (Event event) {
-			if (!DropTarget.this.isDisposed()) {
-				DropTarget.this.dispose();
-			}
+	controlListener = event -> {
+		if (!DropTarget.this.isDisposed()) {
+			DropTarget.this.dispose();
 		}
 	};
 	control.addListener (SWT.Dispose, controlListener);
 
-	this.addListener(SWT.Dispose, new Listener() {
-		@Override
-		public void handleEvent (Event event) {
-			onDispose();
-		}
-	});
+	this.addListener(SWT.Dispose, event -> onDispose());
 
 	Object effect = control.getData(DEFAULT_DROP_TARGET_EFFECT);
 	if (effect instanceof DropTargetEffect) {
@@ -693,9 +688,9 @@ boolean drop(NSObject sender) {
 
 	if (type != null) {
 		tdata.type = Transfer.registerType(type.getString());
-		if (type.isEqual(OS.NSStringPboardType) ||
-				type.isEqual(OS.NSHTMLPboardType) ||
-				type.isEqual(OS.NSRTFPboardType)) {
+		if (type.isEqual(OS.NSPasteboardTypeString) ||
+				type.isEqual(OS.NSPasteboardTypeHTML) ||
+				type.isEqual(OS.NSPasteboardTypeRTF)) {
 			tdata.data = pasteboard.stringForType(type);
 		} else if (type.isEqual(OS.NSURLPboardType) || type.isEqual(OS.kUTTypeURL)) {
 			tdata.data = NSURL.URLFromPasteboard(pasteboard);
@@ -881,6 +876,8 @@ boolean setEventData(NSObject draggingState, DNDEvent event) {
 	NSPoint mouse = draggingState.draggingLocation();
 	NSPoint globalMouse = draggingState.draggingDestinationWindow().convertBaseToScreen(mouse);
 	NSArray screens = NSScreen.screens();
+	if (screens == null) return false;
+
 	NSRect screenRect = new NSScreen(screens.objectAtIndex(0)).frame();
 	globalMouse.y = screenRect.height - globalMouse.y;
 
@@ -913,7 +910,7 @@ boolean setEventData(NSObject draggingState, DNDEvent event) {
  *    <li>ERROR_NULL_ARGUMENT - if transferAgents is null</li>
  * </ul>
  */
-public void setTransfer(Transfer[] transferAgents){
+public void setTransfer(Transfer... transferAgents){
 	if (transferAgents == null) DND.error(SWT.ERROR_NULL_ARGUMENT);
 	this.transferAgents = transferAgents;
 
