@@ -15,7 +15,7 @@
  *
  * IBM
  * -  Binding to permit interfacing between Cairo and SWT
- * -  Copyright (C) 2005, 2012 IBM Corp.  All Rights Reserved.
+ * -  Copyright (C) 2005, 2018 IBM Corp.  All Rights Reserved.
  *
  * ***** END LICENSE BLOCK ***** */
 package org.eclipse.swt.internal.cairo;
@@ -32,6 +32,7 @@ public class Cairo extends Platform {
 	public static final int CAIRO_ANTIALIAS_NONE = 1;
 	public static final int CAIRO_ANTIALIAS_GRAY = 2;
 	public static final int CAIRO_ANTIALIAS_SUBPIXEL = 3;
+	public static final int CAIRO_ANTIALIAS_BEST = 6;
 	public static final int CAIRO_CONTENT_COLOR = 0x1000;
 	public static final int CAIRO_CONTENT_ALPHA = 0x2000;
 	public static final int CAIRO_CONTENT_COLOR_ALPHA = 0x3000;
@@ -74,6 +75,9 @@ public class Cairo extends Platform {
     public static final int CAIRO_SURFACE_TYPE_BEOS = 8;
     public static final int CAIRO_SURFACE_TYPE_DIRECTFB = 9;
     public static final int CAIRO_SURFACE_TYPE_SVG = 10;
+    public static final int CAIRO_REGION_OVERLAP_IN = 0;
+    public static final int CAIRO_REGION_OVERLAP_OUT = 1;
+    public static final int CAIRO_REGION_OVERLAP_PART = 2;
 	public static final int CAIRO_FILTER_FAST = 0;
 	public static final int CAIRO_FILTER_GOOD = 1;
 	public static final int CAIRO_FILTER_BEST = 2;
@@ -91,6 +95,7 @@ public class Cairo extends Platform {
 
 /** 64*/
 public static final native int cairo_path_data_t_sizeof ();
+public static final native int cairo_rectangle_int_t_sizeof ();
 public static final native int cairo_path_t_sizeof ();
 
 /** Natives */
@@ -370,7 +375,6 @@ public static final long /*int*/ cairo_image_surface_create(int format, int widt
 	}
 }
 /**
- * @method flags=dynamic
  * @param surface cast=(cairo_surface_t *)
  */
 public static final native long /*int*/ _cairo_image_surface_get_data(long /*int*/ surface);
@@ -383,7 +387,6 @@ public static final long /*int*/ cairo_image_surface_get_data(long /*int*/ surfa
 	}
 }
 /**
- * @method flags=dynamic
  * @param surface cast=(cairo_surface_t *)
  */
 public static final native int _cairo_image_surface_get_format(long /*int*/ surface);
@@ -416,7 +419,6 @@ public static final int cairo_image_surface_get_width(long /*int*/ surface) {
 	}
 }
 /**
- * @method flags=dynamic
  * @param surface cast=(cairo_surface_t *)
  */
 public static final native int _cairo_image_surface_get_stride(long /*int*/ surface);
@@ -525,16 +527,6 @@ public static final void cairo_matrix_init_scale(double[] matrix, double sx, dou
 	}
 }
 /** @param matrix cast=(cairo_matrix_t *) */
-public static final native void _cairo_matrix_init_translate(double[] matrix, double tx, double ty);
-public static final void cairo_matrix_init_translate(double[] matrix, double tx, double ty) {
-	lock.lock();
-	try {
-		_cairo_matrix_init_translate(matrix, tx, ty);
-	} finally {
-		lock.unlock();
-	}
-}
-/** @param matrix cast=(cairo_matrix_t *) */
 public static final native int _cairo_matrix_invert(double[] matrix);
 public static final int cairo_matrix_invert(double[] matrix) {
 	lock.lock();
@@ -754,7 +746,6 @@ public static final void cairo_pdf_surface_set_size(long /*int*/ surface, double
 	}
 }
 /**
- * @method flags=dynamic
  * @param cairo cast=(cairo_t *)
  */
 public static final native void _cairo_push_group(long /*int*/ cairo);
@@ -767,7 +758,6 @@ public static final void cairo_push_group(long /*int*/ cairo) {
 	}
 }
 /**
- * @method flags=dynamic
  * @param cairo cast=(cairo_t *)
  */
 public static final native void _cairo_pop_group_to_source(long /*int*/ cairo);
@@ -862,6 +852,34 @@ public static final void cairo_scale(long /*int*/ cr, double sx, double sy) {
 		lock.unlock();
 	}
 }
+/**
+ * @method flags=dynamic
+ * @param cr cast=(cairo_surface_t *)
+ */
+public static final native void _cairo_surface_set_device_scale(long /*int*/ cr, double sx, double sy);
+public static final void cairo_surface_set_device_scale(long /*int*/ cr, double sx, double sy) {
+	lock.lock();
+	try {
+		_cairo_surface_set_device_scale(cr, sx, sy);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @method flags=dynamic
+ * @param cr cast=(cairo_surface_t *)
+ * @param sx cast=(double *)
+ * @param sy cast=(double *)
+ */
+public static final native void _cairo_surface_get_device_scale(long /*int*/ cr, double [] sx, double [] sy);
+public static final void cairo_surface_get_device_scale(long /*int*/ cr, double [] sx, double [] sy) {
+	lock.lock();
+	try {
+		_cairo_surface_get_device_scale(cr, sx, sy);
+	} finally {
+		lock.unlock();
+	}
+}
 /**
  * @param cr cast=(cairo_t *)
  * @param family cast=(const char *)
@@ -1108,7 +1126,6 @@ public static final void cairo_surface_finish(long /*int*/ surface) {
 	}
 }
 /**
- * @method flags=dynamic
  * @param surface cast=(cairo_surface_t *)
  */
 public static final native int _cairo_surface_get_type(long /*int*/ surface);
@@ -1121,7 +1138,6 @@ public static final int cairo_surface_get_type(long /*int*/ surface) {
 	}
 }
 /**
- * @method flags=dynamic
  * @param surface cast=(cairo_surface_t *)
  */
 public static final native int _cairo_surface_get_content(long /*int*/ surface);
@@ -1200,6 +1216,7 @@ public static final void cairo_user_to_device_distance(long /*int*/ cr, double[]
 	}
 }
 public static final native int cairo_version();
+
 /**
  * @param dpy cast=(Display *)
  * @param drawable cast=(Drawable)
@@ -1240,7 +1257,9 @@ public static final int cairo_xlib_surface_get_width(long /*int*/ surface) {
 		lock.unlock();
 	}
 }
-/** @method flags=dynamic */
+/**
+ * @param region cast=(cairo_region_t *)
+ */
 public static final native int _cairo_region_num_rectangles(long /*int*/ region);
 public static final int cairo_region_num_rectangles(long /*int*/ region) {
 	lock.lock();
@@ -1250,12 +1269,170 @@ public static final int cairo_region_num_rectangles(long /*int*/ region) {
 		lock.unlock();
 	}
 }
-/** @method flags=dynamic */
+public static final native long /*int*/ _cairo_region_create();
+public static final long /*int*/ cairo_region_create() {
+	lock.lock();
+	try {
+		return _cairo_region_create();
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ */
+public static final native long /*int*/ _cairo_region_copy(long /*int*/ region);
+public static final long /*int*/ cairo_region_copy(long /*int*/ region) {
+	lock.lock();
+	try {
+		 return _cairo_region_copy(region);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ */
+public static final native boolean _cairo_region_contains_point(long /*int*/ region, int x, int y);
+public static final boolean cairo_region_contains_point(long /*int*/ region, int x, int y) {
+	lock.lock();
+	try {
+		return _cairo_region_contains_point(region, x, y);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ * @param rect cast=(cairo_rectangle_int_t *)
+ */
+public static final native long /*int*/ _cairo_region_contains_rectangle(long /*int*/ region, cairo_rectangle_int_t rect);
+public static final long /*int*/ cairo_region_contains_rectangle(long /*int*/ region, cairo_rectangle_int_t rect) {
+	lock.lock();
+	try {
+		return _cairo_region_contains_rectangle(region, rect);
+	} finally {
+		lock.unlock();
+	}
+}
+/** @param region cast=(cairo_region_t *) */
+public static final native void _cairo_region_destroy(long /*int*/ region);
+public static final void cairo_region_destroy(long /*int*/ region) {
+	lock.lock();
+	try {
+		_cairo_region_destroy(region);
+	} finally {
+		lock.unlock();
+	}
+}
+/** @param region cast=(cairo_region_t *) */
+public static final native boolean _cairo_region_is_empty(long /*int*/ region);
+public static final boolean cairo_region_is_empty(long /*int*/ region) {
+	lock.lock();
+	try {
+		return _cairo_region_is_empty(region);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ * @param rectangle cast=(cairo_rectangle_int_t *),flags=no_in
+ */
+public static final native void _cairo_region_get_extents(long /*int*/ region, cairo_rectangle_int_t rectangle);
+public static final void cairo_region_get_extents(long /*int*/ region, cairo_rectangle_int_t rectangle) {
+	lock.lock();
+	try {
+		_cairo_region_get_extents(region, rectangle);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ * @param rectangle cast=(cairo_rectangle_int_t *)
+ */
 public static final native void _cairo_region_get_rectangle(long /*int*/ region, int nth, long /*int*/ rectangle);
 public static final void cairo_region_get_rectangle(long /*int*/ region, int nth, long /*int*/ rectangle) {
 	lock.lock();
 	try {
-		 _cairo_region_get_rectangle(region,nth,rectangle);
+		 _cairo_region_get_rectangle(region, nth, rectangle);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param source1 cast=(cairo_region_t *)
+ * @param source2 cast=(const cairo_region_t *)
+ */
+public static final native void _cairo_region_intersect(long /*int*/ source1, long /*int*/ source2);
+public static final void cairo_region_intersect(long /*int*/ source1, long /*int*/ source2) {
+	lock.lock();
+	try {
+		_cairo_region_intersect(source1, source2);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param rectangle cast=(const cairo_rectangle_int_t *)
+ */
+public static final native long /*int*/ _cairo_region_create_rectangle(cairo_rectangle_int_t rectangle);
+public static final long /*int*/ cairo_region_create_rectangle(cairo_rectangle_int_t rectangle) {
+	lock.lock();
+	try {
+		return _cairo_region_create_rectangle(rectangle);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param source1 cast=(cairo_region_t *)
+ * @param source2 cast=(const cairo_region_t *)
+ */
+public static final native void _cairo_region_subtract(long /*int*/ source1, long /*int*/ source2);
+public static final void cairo_region_subtract(long /*int*/ source1, long /*int*/ source2) {
+	lock.lock();
+	try {
+		_cairo_region_subtract(source1, source2);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ */
+public static final native void _cairo_region_translate(long /*int*/ region, int dx, int dy);
+public static final void cairo_region_translate(long /*int*/ region, int dx, int dy) {
+	lock.lock();
+	try {
+		 _cairo_region_translate(region,dx,dy);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param source1 cast=(cairo_region_t *)
+ * @param source2 cast=(const cairo_region_t *)
+ */
+public static final native void _cairo_region_union(long /*int*/ source1, long /*int*/ source2);
+public static final void cairo_region_union(long /*int*/ source1, long /*int*/ source2) {
+	lock.lock();
+	try {
+		_cairo_region_union(source1, source2);
+	} finally {
+		lock.unlock();
+	}
+}
+/**
+ * @param region cast=(cairo_region_t *)
+ * @param rect cast=(cairo_rectangle_int_t *),flags=no_out
+ */
+public static final native void _cairo_region_union_rectangle(long /*int*/ region, cairo_rectangle_int_t rect);
+public static final void cairo_region_union_rectangle(long /*int*/ region, cairo_rectangle_int_t rect) {
+	lock.lock();
+	try {
+		_cairo_region_union_rectangle(region, rect);
 	} finally {
 		lock.unlock();
 	}
@@ -1272,6 +1449,12 @@ public static final native void memmove(cairo_path_t dest, long /*int*/ src, lon
  * @param size cast=(size_t)
  */
 public static final native void memmove(cairo_path_data_t dest, long /*int*/ src, long /*int*/ size);
+/**
+ * @param dest cast=(void *)
+ * @param src cast=(const void *)
+ * @param size cast=(size_t)
+ */
+public static final native void memmove(cairo_rectangle_int_t dest, long /*int*/ src, long /*int*/ size);
 /**
  * @param dest cast=(void *)
  * @param src cast=(const void *)
