@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    IBM Corporation - initial API and implementation
@@ -24,12 +27,12 @@ public NSTextFieldCell(id id) {
 	super(id);
 }
 
-public void setPlaceholderString(NSString string) {
-	OS.objc_msgSend(this.id, OS.sel_setPlaceholderString_, string != null ? string.id : 0);
+public void setPlaceholderString(NSString placeholderString) {
+	OS.objc_msgSend(this.id, OS.sel_setPlaceholderString_, placeholderString != null ? placeholderString.id : 0);
 }
 
-public void setTextColor(NSColor color) {
-	OS.objc_msgSend(this.id, OS.sel_setTextColor_, color != null ? color.id : 0);
+public void setTextColor(NSColor textColor) {
+	OS.objc_msgSend(this.id, OS.sel_setTextColor_, textColor != null ? textColor.id : 0);
 }
 
 public NSColor textColor() {
