@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2007, 2017 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -12,6 +15,7 @@ package org.eclipse.swt.widgets;
 
 import org.eclipse.swt.*;
 import org.eclipse.swt.graphics.*;
+import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.cocoa.*;
 
 /**
@@ -107,7 +111,7 @@ long /*int*/ attributedSubstringFromRange (long /*int*/ id, long /*int*/ sel, lo
 
 @Override
 long /*int*/ characterIndexForPoint (long /*int*/ id, long /*int*/ sel, long /*int*/ point) {
-	if (!isInlineEnabled ()) return OS.NSNotFound;
+	if (!isInlineEnabled ()) return OS.NSNotFound();
 	NSPoint pt = new NSPoint ();
 	OS.memmove (pt, point, NSPoint.sizeof);
 	NSView view = parent.view;
@@ -119,7 +123,7 @@ long /*int*/ characterIndexForPoint (long /*int*/ id, long /*int*/ sel, long /*i
 	event.y = (int) pt.y;
 	sendEvent (SWT.ImeComposition, event);
 	int offset = event.index + event.count;
-	return offset != -1 ? offset : OS.NSNotFound;
+	return offset != -1 ? offset : OS.NSNotFound();
 }
 
 @Override
@@ -373,7 +377,7 @@ NSRange markedRange (long /*int*/ id, long /*int*/ sel) {
 		range.location = startOffset;
 		range.length = text.length ();
 	} else {
-		range.location = OS.NSNotFound;
+		range.location = OS.NSNotFound();
 	}
 	return range;
 }
@@ -462,7 +466,7 @@ boolean setMarkedText_selectedRange (long /*int*/ id, long /*int*/ sel, long /*i
 		NSRange rangeLimit = new NSRange (), effectiveRange = new NSRange ();
 		rangeLimit.length = length;
 		int rangeCount = 0;
-		long /*int*/ ptr = OS.malloc (NSRange.sizeof);
+		long /*int*/ ptr = C.malloc (NSRange.sizeof);
 		for (int i = 0; i < length;) {
 			NSDictionary attribs = attribStr.attributesAtIndex(i, ptr, rangeLimit);
 			OS.memmove (effectiveRange, ptr, NSRange.sizeof);
@@ -471,7 +475,7 @@ boolean setMarkedText_selectedRange (long /*int*/ id, long /*int*/ sel, long /*i
 			ranges [rangeCount * 2 + 1] = (int)/*64*/(effectiveRange.location + effectiveRange.length - 1);
 			styles [rangeCount++] = getStyle (attribs);
 		}
-		OS.free (ptr);
+		C.free (ptr);
 		if (rangeCount != styles.length) {
 			TextStyle [] newStyles = new TextStyle [rangeCount];
 			System.arraycopy (styles, 0, newStyles, 0, newStyles.length);
