@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -66,10 +66,6 @@ public abstract class Device implements Drawable {
 	Object [] objects;
 	Object trackingLock;
 
-	/* Colormap and reference count */
-	GdkColor [] gdkColors;
-	int [] colorRefCount;
-
 	/* Disposed flag */
 	boolean disposed;
 
@@ -472,23 +468,17 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 
 Point getScreenDPI () {
 	int dpi = 96; //default value
-	if (GTK.GTK3) {
-		if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-			long /*int*/ display = GDK.gdk_display_get_default();
-			long /*int*/ pMonitor = GDK.gdk_display_get_primary_monitor(display);
-			if (pMonitor == 0) {
-				pMonitor = GDK.gdk_display_get_monitor(display, 0);
-			}
-			int widthMM = GDK.gdk_monitor_get_width_mm(pMonitor);
-			int scaleFactor = GDK.gdk_monitor_get_scale_factor(pMonitor);
-			GdkRectangle monitorGeometry = new GdkRectangle ();
-			GDK.gdk_monitor_get_geometry(pMonitor, monitorGeometry);
-			dpi = Compatibility.round (254 * monitorGeometry.width * scaleFactor, widthMM * 10);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		long /*int*/ display = GDK.gdk_display_get_default();
+		long /*int*/ pMonitor = GDK.gdk_display_get_primary_monitor(display);
+		if (pMonitor == 0) {
+			pMonitor = GDK.gdk_display_get_monitor(display, 0);
 		}
-	} else {
-		int widthMM = GDK.gdk_screen_width_mm ();
-		int width = GDK.gdk_screen_width ();
-		dpi = Compatibility.round (254 * width, widthMM * 10);
+		int widthMM = GDK.gdk_monitor_get_width_mm(pMonitor);
+		int scaleFactor = GDK.gdk_monitor_get_scale_factor(pMonitor);
+		GdkRectangle monitorGeometry = new GdkRectangle ();
+		GDK.gdk_monitor_get_geometry(pMonitor, monitorGeometry);
+		dpi = Compatibility.round (254 * monitorGeometry.width * scaleFactor, widthMM * 10);
 	}
 	return new Point (dpi, dpi);
 }
@@ -593,10 +583,7 @@ protected void init () {
 	this.scaleFactor = getDeviceZoom ();
 	DPIUtil.setDeviceZoom (scaleFactor);
 
-	//TODO: Remove; temporary code only
-	boolean fixAIX = OS.IsAIX && C.PTR_SIZEOF == 8;
-
-	if (debug || fixAIX) {
+	if (debug) {
 		if (xDisplay != 0) {
 			/* Create the warning and error callbacks */
 			Class<?> clazz = getClass ();
@@ -665,34 +652,41 @@ protected void init () {
 	GTK.gtk_widget_realize(shellHandle);
 
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long /*int*/ surface = GDK.gdk_window_create_similar_surface(GDK.gdk_get_default_root_window(), Cairo.CAIRO_CONTENT_COLOR, 10, 10);
 		double sx[] = new double[1];
 		double sy[] = new double[1];
+		long /*int*/ gdkResource;
+		long /*int*/ surface;
+		if (GTK.GTK4) {
+			GTK.gtk_widget_realize(shellHandle);
+			gdkResource = GTK.gtk_widget_get_surface(shellHandle);
+			surface = GDK.gdk_surface_create_similar_surface(gdkResource, Cairo.CAIRO_CONTENT_COLOR, 10, 10);
+		} else {
+			gdkResource = GDK.gdk_get_default_root_window();
+			surface = GDK.gdk_window_create_similar_surface(gdkResource, Cairo.CAIRO_CONTENT_COLOR, 10, 10);
+		}
 		Cairo.cairo_surface_get_device_scale(surface, sx, sy);
-
 		DPIUtil.setUseCairoAutoScale((sx[0]*100) == scaleFactor);
 	}
 
 	/* Initialize the system font slot */
 	long /*int*/ [] defaultFontArray = new long /*int*/ [1];
 	long /*int*/ defaultFont;
-	if (GTK.GTK3) {
-		long /*int*/ context = GTK.gtk_widget_get_style_context (shellHandle);
-		if ((GTK.GTK_VERSION < OS.VERSION(3, 8, 0))|| ("ppc64le".equals(System.getProperty("os.arch")))) {
-			defaultFont = GTK.gtk_style_context_get_font (context, GTK.GTK_STATE_FLAG_NORMAL);
-		} else if (GTK.GTK_VERSION >= OS.VERSION(3, 18, 0)) {
-			GTK.gtk_style_context_save(context);
-			GTK.gtk_style_context_set_state(context, GTK.GTK_STATE_FLAG_NORMAL);
-			GTK.gtk_style_context_get(context, GTK.GTK_STATE_FLAG_NORMAL, GTK.gtk_style_property_font, defaultFontArray, 0);
-			GTK.gtk_style_context_restore(context);
-			defaultFont = defaultFontArray [0];
+	long /*int*/ context = GTK.gtk_widget_get_style_context (shellHandle);
+	if ((GTK.GTK_VERSION < OS.VERSION(3, 8, 0))|| ("ppc64le".equals(System.getProperty("os.arch")))) {
+		defaultFont = GTK.gtk_style_context_get_font (context, GTK.GTK_STATE_FLAG_NORMAL);
+	} else if (GTK.GTK_VERSION >= OS.VERSION(3, 18, 0)) {
+		GTK.gtk_style_context_save(context);
+		GTK.gtk_style_context_set_state(context, GTK.GTK_STATE_FLAG_NORMAL);
+		if (GTK.GTK4) {
+			GTK.gtk_style_context_get(context, GTK.gtk_style_property_font, defaultFontArray, 0);
 		} else {
 			GTK.gtk_style_context_get(context, GTK.GTK_STATE_FLAG_NORMAL, GTK.gtk_style_property_font, defaultFontArray, 0);
-			defaultFont = defaultFontArray [0];
 		}
+		GTK.gtk_style_context_restore(context);
+		defaultFont = defaultFontArray [0];
 	} else {
-		long /*int*/ style = GTK.gtk_widget_get_style (shellHandle);
-		defaultFont = GTK.gtk_style_get_font_desc (style);
+		GTK.gtk_style_context_get(context, GTK.GTK_STATE_FLAG_NORMAL, GTK.gtk_style_property_font, defaultFontArray, 0);
+		defaultFont = defaultFontArray [0];
 	}
 	defaultFont = OS.pango_font_description_copy (defaultFont);
 	Point dpi = getDPI(), screenDPI = getScreenDPI();
@@ -702,9 +696,7 @@ protected void init () {
 	}
 	systemFont = Font.gtk_new (this, defaultFont);
 
-	if (GTK.GTK3) {
-		overrideThemeValues();
-	}
+	overrideThemeValues();
 }
 
 /**
@@ -724,13 +716,7 @@ protected void init () {
  * Note that much of eclipse 'dark theme' is done by platform.ui's CSS engine, not by SWT.
  */
 private void overrideThemeValues () {
-	assert GTK.GTK3;
-	long /*int*/ screen = GDK.gdk_screen_get_default();
 	long /*int*/ provider = GTK.gtk_css_provider_new();
-	if (screen == 0 || provider == 0) {
-		System.err.println("SWT Warning: Override of theme values failed. Reason: could not acquire screen or provider.");
-		return;
-	}
 
 	BiFunction <String, Boolean, String> load = (path, isResource) -> {
 		try  {
@@ -781,7 +767,21 @@ private void overrideThemeValues () {
 		combinedCSS.append(load.apply(additionalCSSPath, false));
 	}
 
-	GTK.gtk_style_context_add_provider_for_screen (screen, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	if (GTK.GTK4) {
+		long /*int*/ display = GDK.gdk_display_get_default();
+		if (display == 0 || provider == 0) {
+			System.err.println("SWT Warning: Override of theme values failed. Reason: could not acquire display or provider.");
+			return;
+		}
+		GTK.gtk_style_context_add_provider_for_display (display, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	} else {
+		long /*int*/ screen = GDK.gdk_screen_get_default();
+		if (screen == 0 || provider == 0) {
+			System.err.println("SWT Warning: Override of theme values failed. Reason: could not acquire screen or provider.");
+			return;
+		}
+		GTK.gtk_style_context_add_provider_for_screen (screen, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	}
 	GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (combinedCSS.toString(), true), -1, null);
 }
 
@@ -937,23 +937,6 @@ protected void release () {
 	if (systemFont != null) systemFont.dispose ();
 	systemFont = null;
 
-	if (gdkColors != null) {
-		if (!GTK.GTK3) {
-			long /*int*/ colormap = GDK.gdk_colormap_get_system();
-			for (int i = 0; i < gdkColors.length; i++) {
-				GdkColor color = gdkColors [i];
-				if (color != null) {
-					while (colorRefCount [i] > 0) {
-						GDK.gdk_colormap_free_colors(colormap, color, 1);
-						--colorRefCount [i];
-					}
-				}
-			}
-		}
-	}
-	gdkColors = null;
-	colorRefCount = null;
-
 	if (COLOR_BLACK != null) COLOR_BLACK.dispose();
 	if (COLOR_DARK_RED != null) COLOR_DARK_RED.dispose();
 	if (COLOR_DARK_GREEN != null) COLOR_DARK_GREEN.dispose();
@@ -1048,9 +1031,7 @@ static long /*int*/ XErrorProc (long /*int*/ xDisplay, long /*int*/ xErrorEvent)
 			if (DEBUG || device.debug) {
 				new SWTError ().printStackTrace ();
 			}
-			//TODO: Remove; temporary code only
-			boolean fixAIX = OS.IsAIX && C.PTR_SIZEOF == 8;
-			if (!fixAIX) OS.Call (XErrorProc, xDisplay, xErrorEvent);
+			OS.Call (XErrorProc, xDisplay, xErrorEvent);
 		}
 	} else {
 		if (DEBUG) new SWTError ().printStackTrace ();
@@ -1090,10 +1071,20 @@ int _getDPIx () {
  * @since 3.105
  */
 protected int getDeviceZoom() {
-	long /*int*/ screen = GDK.gdk_screen_get_default();
-	int dpi = (int) GDK.gdk_screen_get_resolution (screen);
-	if (dpi <= 0) dpi = 96; // gdk_screen_get_resolution returns -1 in case of error
-	if (GTK.GTK_VERSION > OS.VERSION(3, 9, 0)) {
+	/*
+	 * We can hard-code 96 as gdk_screen_get_resolution will always return -1
+	 * if gdk_screen_set_resolution has not been called.
+	 */
+	int dpi = 96;
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		long /*int*/ display = GDK.gdk_display_get_default();
+		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, 0, 0);
+		int scale = GDK.gdk_monitor_get_scale_factor(monitor);
+		dpi = dpi * scale;
+	} else if (GTK.GTK_VERSION > OS.VERSION(3, 9, 0)) {
+		long /*int*/ screen = GDK.gdk_screen_get_default();
+		dpi = (int) GDK.gdk_screen_get_resolution (screen);
+		if (dpi <= 0) dpi = 96; // gdk_screen_get_resolution returns -1 in case of error
 		int monitor_num = GDK.gdk_screen_get_monitor_at_point (screen, 0, 0);
 		int scale = GDK.gdk_screen_get_monitor_scale_factor (screen, monitor_num);
 		dpi = dpi * scale;
