@@ -87,20 +87,6 @@ public final class Image extends Resource implements Drawable {
 	 */
 	public int type;
 
-	/**
-	 * The handle to the OS pixmap resource.
-	 * (Warning: This field is platform dependent)
-	 * <p>
-	 * <b>IMPORTANT:</b> This field is <em>not</em> part of the SWT
-	 * public API. It is marked public only so that it can be shared
-	 * within the packages provided by SWT. It is not available on all
-	 * platforms and should never be accessed from application code.
-	 * </p>
-	 *
-	 * @noreference This field is not intended to be referenced by clients.
-	 */
-	public long /*int*/ pixmap;
-
 	/**
 	 * The handle to the OS mask resource.
 	 * (Warning: This field is platform dependent)
@@ -303,7 +289,7 @@ public Image(Device device, Image srcImage, int flag) {
 	boolean hasAlpha = format == Cairo.CAIRO_FORMAT_ARGB32;
 	surface = Cairo.cairo_image_surface_create(format, width, height);
 	if (surface == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-	if (GTK.GTK3 && DPIUtil.useCairoAutoScale()) {
+	if (DPIUtil.useCairoAutoScale()) {
 		double scaleFactor = DPIUtil.getDeviceZoom() / 100f;
 		Cairo.cairo_surface_set_device_scale(surface, scaleFactor, scaleFactor);
 	}
@@ -671,7 +657,7 @@ public Image(Device device, ImageFileNameProvider imageFileNameProvider) {
 	String filename = DPIUtil.validateAndGetImagePathAtZoom (imageFileNameProvider, currentDeviceZoom, found);
 	if (found[0]) {
 		initNative (filename);
-		if (this.pixmap == 0 && this.surface == 0) {
+		if (this.surface == 0) {
 			ImageData data = new ImageData(filename);
 			init(data);
 		}
@@ -745,7 +731,7 @@ boolean refreshImageForZoom () {
 				/* Release current native resources */
 				destroy ();
 				initNative(filename);
-				if (this.pixmap == 0 && this.surface == 0) {
+				if (this.surface == 0) {
 					ImageData data = new ImageData(filename);
 					init(data);
 				}
@@ -828,7 +814,7 @@ void createFromPixbuf(int type, long /*int*/ pixbuf) {
 	int format = hasAlpha ? Cairo.CAIRO_FORMAT_ARGB32 : Cairo.CAIRO_FORMAT_RGB24;
 	surface = Cairo.cairo_image_surface_create(format, width, height);
 	if (surface == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-	if (GTK.GTK3&&DPIUtil.useCairoAutoScale()) {
+	if (DPIUtil.useCairoAutoScale()) {
 		double scaleFactor = DPIUtil.getDeviceZoom() / 100f;
 		Cairo.cairo_surface_set_device_scale(surface, scaleFactor, scaleFactor);
 	}
@@ -924,129 +910,6 @@ void createMask() {
 
 void createSurface() {
 	if (surface != 0) return;
-	/* There is no pixmaps in GTK 3. */
-	if (GTK.GTK3) return;
-	/* Generate the mask if necessary. */
-	if (transparentPixel != -1) createMask();
-	int[] w = new int[1], h = new int[1];
-	GDK.gdk_pixmap_get_size(pixmap, w, h);
-	int width = w[0], height = h[0];
-	this.width = width;
-	this.height = height;
-	if (mask != 0 || alpha != -1 || alphaData != null) {
-	 	long /*int*/ pixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, true, 8, width, height);
-		if (pixbuf == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-		long /*int*/ colormap = GDK.gdk_colormap_get_system();
-		GDK.gdk_pixbuf_get_from_drawable(pixbuf, pixmap, colormap, 0, 0, 0, 0, width, height);
-		int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
-		long /*int*/ pixels = GDK.gdk_pixbuf_get_pixels(pixbuf);
-		byte[] line = new byte[stride];
-		int oa, or, og, ob;
-		if (OS.BIG_ENDIAN) {
-			oa = 0; or = 1; og = 2; ob = 3;
-		} else {
-			oa = 3; or = 2; og = 1; ob = 0;
-		}
-		if (mask != 0 && GDK.gdk_drawable_get_depth(mask) == 1) {
-			long /*int*/ maskPixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, false, 8, width, height);
-			if (maskPixbuf == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-			GDK.gdk_pixbuf_get_from_drawable(maskPixbuf, mask, 0, 0, 0, 0, 0, width, height);
-			int maskStride = GDK.gdk_pixbuf_get_rowstride(maskPixbuf);
-			long /*int*/ maskPixels = GDK.gdk_pixbuf_get_pixels(maskPixbuf);
-			byte[] maskLine = new byte[maskStride];
-			long /*int*/ offset = pixels, maskOffset = maskPixels;
-			for (int y=0; y<height; y++) {
-				C.memmove(line, offset, stride);
-				C.memmove(maskLine, maskOffset, maskStride);
-				for (int x=0, offset1=0; x<width; x++, offset1 += 4) {
-					if (maskLine[x * 3] == 0) {
-						line[offset1 + 0] = line[offset1 + 1] = line[offset1 + 2] = line[offset1 + 3] = 0;
-					} else {
-						byte r = line[offset1 + 0];
-						byte g = line[offset1 + 1];
-						byte b = line[offset1 + 2];
-						line[offset1 + oa] = (byte)0xFF;
-						line[offset1 + or] = r;
-						line[offset1 + og] = g;
-						line[offset1 + ob] = b;
-					}
-				}
-				C.memmove(offset, line, stride);
-				offset += stride;
-				maskOffset += maskStride;
-			}
-			OS.g_object_unref(maskPixbuf);
-		} else if (alpha != -1) {
-			long /*int*/ offset = pixels;
-			for (int y=0; y<height; y++) {
-				C.memmove(line, offset, stride);
-				for (int x=0, offset1=0; x<width; x++, offset1 += 4) {
-					/* pre-multiplied alpha */
-					int r = ((line[offset1 + 0] & 0xFF) * alpha) + 128;
-					r = (r + (r >> 8)) >> 8;
-					int g = ((line[offset1 + 1] & 0xFF) * alpha) + 128;
-					g = (g + (g >> 8)) >> 8;
-					int b = ((line[offset1 + 2] & 0xFF) * alpha) + 128;
-					b = (b + (b >> 8)) >> 8;
-					line[offset1 + oa] = (byte)alpha;
-					line[offset1 + or] = (byte)r;
-					line[offset1 + og] = (byte)g;
-					line[offset1 + ob] = (byte)b;
-				}
-				C.memmove(offset, line, stride);
-				offset += stride;
-			}
-		} else if (alphaData != null) {
-			long /*int*/ offset = pixels;
-			for (int y = 0; y < h [0]; y++) {
-				C.memmove (line, offset, stride);
-				for (int x=0, offset1=0; x<width; x++, offset1 += 4) {
-					int alpha = alphaData [y*w [0]+x] & 0xFF;
-					/* pre-multiplied alpha */
-					int r = ((line[offset1 + 0] & 0xFF) * alpha) + 128;
-					r = (r + (r >> 8)) >> 8;
-					int g = ((line[offset1 + 1] & 0xFF) * alpha) + 128;
-					g = (g + (g >> 8)) >> 8;
-					int b = ((line[offset1 + 2] & 0xFF) * alpha) + 128;
-					b = (b + (b >> 8)) >> 8;
-					line[offset1 + oa] = (byte)alpha;
-					line[offset1 + or] = (byte)r;
-					line[offset1 + og] = (byte)g;
-					line[offset1 + ob] = (byte)b;
-				}
-				C.memmove (offset, line, stride);
-				offset += stride;
-			}
-		} else {
-			long /*int*/ offset = pixels;
-			for (int y = 0; y < h [0]; y++) {
-				C.memmove (line, offset, stride);
-				for (int x=0, offset1=0; x<width; x++, offset1 += 4) {
-					byte r = line[offset1 + 0];
-					byte g = line[offset1 + 1];
-					byte b = line[offset1 + 2];
-					line[offset1 + oa] = (byte)0xFF;
-					line[offset1 + or] = r;
-					line[offset1 + og] = g;
-					line[offset1 + ob] = b;
-				}
-				C.memmove (offset, line, stride);
-				offset += stride;
-			}
-		}
-		surface = Cairo.cairo_image_surface_create(Cairo.CAIRO_FORMAT_ARGB32, width, height);
-		long /*int*/ data = Cairo.cairo_image_surface_get_data(surface);
-		C.memmove(data, pixels, stride * height);
-		Cairo.cairo_surface_mark_dirty(surface);
-		OS.g_object_unref(pixbuf);
-	} else {
-		long /*int*/ xDisplay = GDK.gdk_x11_display_get_xdisplay(GDK.gdk_display_get_default());
-		long /*int*/ xDrawable = GDK.GDK_PIXMAP_XID(pixmap);
-		long /*int*/ xVisual = GDK.gdk_x11_visual_get_xvisual(GDK.gdk_visual_get_system());
-		surface = Cairo.cairo_xlib_surface_create(xDisplay, xDrawable, xVisual, width, height);
-	}
-	/* Destroy the image mask if the there is a GC created on the image */
-	if (transparentPixel != -1 && memGC != null) destroyMask();
 }
 
 /**
@@ -1061,10 +924,9 @@ void destroyMask() {
 @Override
 void destroy() {
 	if (memGC != null) memGC.dispose();
-	if (pixmap != 0) OS.g_object_unref(pixmap);
 	if (mask != 0) OS.g_object_unref(mask);
 	if (surface != 0) Cairo.cairo_surface_destroy(surface);
-	surface = pixmap = mask = 0;
+	surface = mask = 0;
 	memGC = null;
 }
 
@@ -1155,9 +1017,8 @@ public Rectangle getBoundsInPixels() {
 	if (width != -1 && height != -1) {
 		return new Rectangle(0, 0, width, height);
 	}
-	int[] w = new int[1]; int[] h = new int[1];
-	GDK.gdk_pixmap_get_size(pixmap, w, h);
-	return new Rectangle(0, 0, width = w[0], height = h[0]);
+	// There are no pixmaps on GTK3, so this will just return 0
+	return new Rectangle(0, 0, 0, 0);
 }
 
 /**
@@ -1272,7 +1133,7 @@ public ImageData getImageDataAtCurrentZoom () {
  *
  * @param zoom
  *            The zoom level in % of the standard resolution (which is 1
- *            physical monitor pixel == 1 SWT logical pixel). Typically 100,
+ *            physical monitor pixel == 1 SWT logical point). Typically 100,
  *            150, or 200.
  * @return an <code>ImageData</code> containing the image's data and
  *         attributes at the given zoom level
@@ -1297,7 +1158,7 @@ public ImageData getImageData (int zoom) {
 			return data;
 		}
 		// AutoScale the image at 100% zoom
-		return DPIUtil.autoScaleUp (device, data);
+		return DPIUtil.autoScaleImageData (device, data, zoom, 100);
 	} else if (imageFileNameProvider != null) {
 		boolean[] found = new boolean[1];
 		String fileName = DPIUtil.validateAndGetImagePathAtZoom (imageFileNameProvider, zoom, found);
@@ -1306,7 +1167,7 @@ public ImageData getImageData (int zoom) {
 			return new ImageData (fileName);
 		}
 		// AutoScale the image at 100% zoom
-		return DPIUtil.autoScaleUp (device, new ImageData (fileName));
+		return DPIUtil.autoScaleImageData (device, new ImageData (fileName), zoom, 100);
 	} else {
 		return DPIUtil.autoScaleImageData (device, getImageDataAtCurrentZoom (), zoom, currentDeviceZoom);
 	}
@@ -1332,12 +1193,7 @@ public ImageData getImageData (int zoom) {
 public static Image gtk_new(Device device, int type, long /*int*/ imageHandle, long /*int*/ mask) {
 	Image image = new Image(device);
 	image.type = type;
-	if (GTK.GTK3) {
-		image.surface = imageHandle;
-	} else {
-		image.pixmap = imageHandle;
-		image.createSurface();
-	}
+	image.surface = imageHandle;
 	image.mask = mask;
 	return image;
 }
@@ -1397,7 +1253,7 @@ void init(int width, int height) {
 	if (surface == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	// When we create a blank image we need to set it to 100 in GTK3 as we draw using 100% scale.
 	// Cairo will take care of scaling for us when image needs to be scaled.
-	if (GTK.GTK3 && DPIUtil.useCairoAutoScale()) {
+	if (DPIUtil.useCairoAutoScale()) {
 		currentDeviceZoom = 100;
 		Cairo.cairo_surface_set_device_scale(surface, 1f, 1f);
 	} else {
@@ -1425,7 +1281,7 @@ void init(ImageData image) {
 	int format = hasAlpha ? Cairo.CAIRO_FORMAT_ARGB32 : Cairo.CAIRO_FORMAT_RGB24;
 	surface = Cairo.cairo_image_surface_create(format, width, height);
 	if (surface == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-	if (GTK.GTK3 && DPIUtil.useCairoAutoScale()) {
+	if (DPIUtil.useCairoAutoScale()) {
 		double scaleFactor = DPIUtil.getDeviceZoom() / 100f;
 		Cairo.cairo_surface_set_device_scale(surface, scaleFactor, scaleFactor);
 	}
@@ -1586,14 +1442,8 @@ public long /*int*/ internal_new_GC (GCData data) {
 			}
 		}
 		data.device = device;
-		data.drawable = pixmap;
-		if (GTK.GTK3) {
-			data.foregroundRGBA = device.COLOR_BLACK.handleRGBA;
-			data.backgroundRGBA = device.COLOR_WHITE.handleRGBA;
-		} else {
-			data.background = device.COLOR_WHITE.handle;
-			data.foreground = device.COLOR_BLACK.handle;
-		}
+		data.foregroundRGBA = device.COLOR_BLACK.handle;
+		data.backgroundRGBA = device.COLOR_WHITE.handle;
 		data.font = device.systemFont;
 		data.image = this;
 	}
