@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -84,7 +84,7 @@ public Region() {
  */
 public Region(Device device) {
 	super(device);
-	handle = GDK.gdk_region_new();
+	handle = Cairo.cairo_region_create();
 	if (handle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	init();
 }
@@ -95,9 +95,6 @@ Region(Device device, long /*int*/ handle) {
 }
 
 static long /*int*/ gdk_region_polygon(int[] pointArray, int npoints, int fill_rule) {
-	if (!GTK.GTK3) {
-		return GDK.gdk_region_polygon(pointArray, npoints, fill_rule);
-	}
 	//TODO this does not perform well and could fail if the polygon is too big
 	int minX = pointArray[0], maxX = minX;
 	int minY = pointArray[1], maxY = minY;
@@ -127,21 +124,17 @@ static long /*int*/ gdk_region_polygon(int[] pointArray, int npoints, int fill_r
 	Cairo.cairo_fill(cairo);
 	Cairo.cairo_destroy(cairo);
 	long /*int*/ polyRgn = GDK.gdk_cairo_region_create_from_surface(surface);
-	GDK.gdk_region_offset (polyRgn, minX, minY);
+	Cairo.cairo_region_translate (polyRgn, minX, minY);
 	Cairo.cairo_surface_destroy(surface);
 	return polyRgn;
 }
 
-static void gdk_region_get_rectangles(long /*int*/ region, long /*int*/[] rectangles, int[] n_rectangles) {
-	if (!GTK.GTK3) {
-		GDK.gdk_region_get_rectangles (region, rectangles, n_rectangles);
-		return;
-	}
+static void cairo_region_get_rectangles(long /*int*/ region, long /*int*/[] rectangles, int[] n_rectangles) {
 	int num = Cairo.cairo_region_num_rectangles (region);
 	if (n_rectangles != null) n_rectangles[0] = num;
-	rectangles[0] = OS.g_malloc(GdkRectangle.sizeof * num);
+	rectangles[0] = OS.g_malloc(cairo_rectangle_int_t.sizeof * num);
 	for (int n = 0; n < num; n++) {
-		Cairo.cairo_region_get_rectangle (region, n, rectangles[0] + (n * GdkRectangle.sizeof));
+		Cairo.cairo_region_get_rectangle (region, n, rectangles[0] + (n * cairo_rectangle_int_t.sizeof));
 	}
 }
 
@@ -174,8 +167,8 @@ void addInPixels (int[] pointArray) {
 	*/
 	if (pointArray.length < 6) return;
 	long /*int*/ polyRgn = gdk_region_polygon(pointArray, pointArray.length / 2, GDK.GDK_EVEN_ODD_RULE);
-	GDK.gdk_region_union(handle, polyRgn);
-	GDK.gdk_region_destroy(polyRgn);
+	Cairo.cairo_region_union(handle, polyRgn);
+	Cairo.cairo_region_destroy(polyRgn);
 }
 
 /**
@@ -225,12 +218,12 @@ public void add(int x, int y, int width, int height) {
 	add(new Rectangle(x, y, width, height));
 }
 void addInPixels(int x, int y, int width, int height) {
-	GdkRectangle gdkRect = new GdkRectangle();
-	gdkRect.x = x;
-	gdkRect.y = y;
-	gdkRect.width = width;
-	gdkRect.height = height;
-	GDK.gdk_region_union_with_rect(handle, gdkRect);
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
+	rect.x = x;
+	rect.y = y;
+	rect.width = width;
+	rect.height = height;
+	Cairo.cairo_region_union_rectangle(handle, rect);
 }
 
 /**
@@ -252,7 +245,7 @@ public void add(Region region) {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	if (region == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
 	if (region.isDisposed()) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
-	GDK.gdk_region_union(handle, region.handle);
+	Cairo.cairo_region_union(handle, region.handle);
 }
 
 /**
@@ -273,7 +266,7 @@ public boolean contains(int x, int y) {
 	return contains(new Point(x, y));
 }
 boolean containsInPixels(int x, int y) {
-	return GDK.gdk_region_point_in(handle, x, y);
+	return Cairo.cairo_region_contains_point(handle, x, y);
 }
 
 /**
@@ -302,7 +295,7 @@ boolean containsInPixels(Point pt) {
 
 @Override
 void destroy() {
-	GDK.gdk_region_destroy(handle);
+	Cairo.cairo_region_destroy(handle);
 	handle = 0;
 }
 
@@ -342,9 +335,9 @@ public Rectangle getBounds() {
 	return DPIUtil.autoScaleDown(getBoundsInPixels());
 }
 Rectangle getBoundsInPixels() {
-	GdkRectangle gdkRect = new GdkRectangle();
-	GDK.gdk_region_get_clipbox(handle, gdkRect);
-	return new Rectangle(gdkRect.x, gdkRect.y, gdkRect.width, gdkRect.height);
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
+	Cairo.cairo_region_get_extents(handle, rect);
+	return new Rectangle(rect.x, rect.y, rect.width, rect.height);
 }
 
 /**
@@ -433,14 +426,14 @@ public void intersect(int x, int y, int width, int height) {
 }
 
 void intersectInPixels(int x, int y, int width, int height) {
-	GdkRectangle gdkRect = new GdkRectangle();
-	gdkRect.x = x;
-	gdkRect.y = y;
-	gdkRect.width = width;
-	gdkRect.height = height;
-	long /*int*/ rectRgn = GDK.gdk_region_rectangle(gdkRect);
-	GDK.gdk_region_intersect(handle, rectRgn);
-	GDK.gdk_region_destroy(rectRgn);
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
+	rect.x = x;
+	rect.y = y;
+	rect.width = width;
+	rect.height = height;
+	long /*int*/ rectRgn = Cairo.cairo_region_create_rectangle(rect);
+	Cairo.cairo_region_intersect(handle, rectRgn);
+	Cairo.cairo_region_destroy(rectRgn);
 }
 
 /**
@@ -464,7 +457,7 @@ public void intersect(Region region) {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	if (region == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
 	if (region.isDisposed()) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
-	GDK.gdk_region_intersect(handle, region.handle);
+	Cairo.cairo_region_intersect(handle, region.handle);
 }
 
 /**
@@ -490,12 +483,12 @@ public boolean intersects (int x, int y, int width, int height) {
 }
 
 boolean intersectsInPixels (int x, int y, int width, int height) {
-	GdkRectangle gdkRect = new GdkRectangle();
-	gdkRect.x = x;
-	gdkRect.y = y;
-	gdkRect.width = width;
-	gdkRect.height = height;
-	return GDK.gdk_region_rect_in(handle, gdkRect) != GDK.GDK_OVERLAP_RECTANGLE_OUT;
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
+	rect.x = x;
+	rect.y = y;
+	rect.width = width;
+	rect.height = height;
+	return Cairo.cairo_region_contains_rectangle(handle, rect) != Cairo.CAIRO_REGION_OVERLAP_OUT;
 }
 /**
  * Returns <code>true</code> if the given rectangle intersects
@@ -552,7 +545,7 @@ public boolean isDisposed() {
  */
 public boolean isEmpty() {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
-	return GDK.gdk_region_empty(handle);
+	return Cairo.cairo_region_is_empty(handle);
 }
 
 /**
@@ -584,8 +577,8 @@ void subtractInPixels (int[] pointArray) {
 	*/
 	if (pointArray.length < 6) return;
 	long /*int*/ polyRgn = gdk_region_polygon(pointArray, pointArray.length / 2, GDK.GDK_EVEN_ODD_RULE);
-	GDK.gdk_region_subtract(handle, polyRgn);
-	GDK.gdk_region_destroy(polyRgn);
+	Cairo.cairo_region_subtract(handle, polyRgn);
+	Cairo.cairo_region_destroy(polyRgn);
 }
 /**
  * Subtracts the given rectangle from the collection of polygons
@@ -638,14 +631,14 @@ public void subtract(int x, int y, int width, int height) {
 }
 
 void subtractInPixels(int x, int y, int width, int height) {
-	GdkRectangle gdkRect = new GdkRectangle();
-	gdkRect.x = x;
-	gdkRect.y = y;
-	gdkRect.width = width;
-	gdkRect.height = height;
-	long /*int*/ rectRgn = GDK.gdk_region_rectangle(gdkRect);
-	GDK.gdk_region_subtract(handle, rectRgn);
-	GDK.gdk_region_destroy(rectRgn);
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t ();
+	rect.x = x;
+	rect.y = y;
+	rect.width = width;
+	rect.height = height;
+	long /*int*/ rectRgn = Cairo.cairo_region_create_rectangle(rect);
+	Cairo.cairo_region_subtract(handle, rectRgn);
+	Cairo.cairo_region_destroy(rectRgn);
 }
 
 /**
@@ -669,7 +662,7 @@ public void subtract(Region region) {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	if (region == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
 	if (region.isDisposed()) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
-	GDK.gdk_region_subtract(handle, region.handle);
+	Cairo.cairo_region_subtract(handle, region.handle);
 }
 
 /**
@@ -691,7 +684,7 @@ public void translate (int x, int y) {
 }
 
 void translateInPixels (int x, int y) {
-	GDK.gdk_region_offset (handle, x, y);
+	Cairo.cairo_region_translate (handle, x, y);
 }
 
 /**
