@@ -62,6 +62,7 @@ public final class TextLayout extends Resource {
 	int stylesCount;
 	long /*int*/ layout, context, attrList, selAttrList;
 	int[] invalidOffsets;
+	int verticalIndentInPoints;
 	static final char LTR_MARK = '\u200E', RTL_MARK = '\u200F', ZWS = '\u200B', ZWNBS = '\uFEFF';
 
 /**
@@ -221,16 +222,11 @@ void computeRuns () {
 					if (style.foreground == null) {
 						// Bug 497071: use COLOR_LINK_FOREGROUND for StyledText links
 						long /*int*/ attr;
-						if (GTK.GTK3) {
-							GdkRGBA linkRGBA = device.getSystemColor(SWT.COLOR_LINK_FOREGROUND).handleRGBA;
-							// Manual conversion since PangoAttrColor is a special case.
-							// It uses GdkColor style colors but is supported on GTK3.
-							attr = OS.pango_attr_foreground_new((short)(linkRGBA.red * 0xFFFF),
-									(short)(linkRGBA.green * 0xFFFF), (short)(linkRGBA.blue * 0xFFFF));
-						} else {
-							GdkColor linkColor = device.getSystemColor(SWT.COLOR_LINK_FOREGROUND).handle;
-							attr = OS.pango_attr_foreground_new(linkColor.red, linkColor.green, linkColor.blue);
-						}
+						GdkRGBA linkRGBA = device.getSystemColor(SWT.COLOR_LINK_FOREGROUND).handle;
+						// Manual conversion since PangoAttrColor is a special case.
+						// It uses GdkColor style colors but is supported on GTK3.
+						attr = OS.pango_attr_foreground_new((short)(linkRGBA.red * 0xFFFF),
+								(short)(linkRGBA.green * 0xFFFF), (short)(linkRGBA.blue * 0xFFFF));
 						OS.memmove (attribute, attr, PangoAttribute.sizeof);
 						attribute.start_index = byteStart;
 						attribute.end_index = byteEnd;
@@ -249,14 +245,9 @@ void computeRuns () {
 			OS.pango_attr_list_insert(attrList, attr);
 			OS.pango_attr_list_insert(selAttrList, OS.pango_attribute_copy(attr));
 			if (style.underlineColor != null) {
-				if (GTK.GTK3) {
-					GdkRGBA rgba = style.underlineColor.handleRGBA;
-					attr = OS.pango_attr_underline_color_new((short)(rgba.red * 0xFFFF),
-							(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
-				} else {
-					GdkColor fg = style.underlineColor.handle;
-					attr = OS.pango_attr_underline_color_new(fg.red, fg.green, fg.blue);
-				}
+				GdkRGBA rgba = style.underlineColor.handle;
+				attr = OS.pango_attr_underline_color_new((short)(rgba.red * 0xFFFF),
+						(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
 				if (attr != 0) {
 					OS.memmove(attribute, attr, PangoAttribute.sizeof);
 					attribute.start_index = byteStart;
@@ -276,14 +267,9 @@ void computeRuns () {
 			OS.pango_attr_list_insert(attrList, attr);
 			OS.pango_attr_list_insert(selAttrList, OS.pango_attribute_copy(attr));
 			if (style.strikeoutColor != null) {
-				if (GTK.GTK3) {
-					GdkRGBA rgba = style.strikeoutColor.handleRGBA;
-					attr = OS.pango_attr_strikethrough_color_new((short)(rgba.red * 0xFFFF),
-							(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
-				} else {
-					GdkColor fg = style.strikeoutColor.handle;
-					attr = OS.pango_attr_strikethrough_color_new(fg.red, fg.green, fg.blue);
-				}
+				GdkRGBA rgba = style.strikeoutColor.handle;
+				attr = OS.pango_attr_strikethrough_color_new((short)(rgba.red * 0xFFFF),
+						(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
 				if (attr != 0) {
 					OS.memmove(attribute, attr, PangoAttribute.sizeof);
 					attribute.start_index = byteStart;
@@ -297,14 +283,9 @@ void computeRuns () {
 		Color foreground = style.foreground;
 		if (foreground != null && !foreground.isDisposed()) {
 			long /*int*/ attr;
-			if (GTK.GTK3) {
-				GdkRGBA rgba = foreground.handleRGBA;
-				attr = OS.pango_attr_foreground_new((short)(rgba.red * 0xFFFF),
-						(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
-			} else {
-				GdkColor fg = foreground.handle;
-				attr = OS.pango_attr_foreground_new(fg.red, fg.green, fg.blue);
-			}
+			GdkRGBA rgba = foreground.handle;
+			attr = OS.pango_attr_foreground_new((short)(rgba.red * 0xFFFF),
+					(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
 			OS.memmove (attribute, attr, PangoAttribute.sizeof);
 			attribute.start_index = byteStart;
 			attribute.end_index = byteEnd;
@@ -314,14 +295,9 @@ void computeRuns () {
 		Color background = style.background;
 		if (background != null && !background.isDisposed()) {
 			long /*int*/ attr;
-			if (GTK.GTK3) {
-				GdkRGBA rgba = background.handleRGBA;
-				attr = OS.pango_attr_background_new((short)(rgba.red * 0xFFFF),
-						(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
-			} else {
-				GdkColor bg = background.handle;
-				attr = OS.pango_attr_background_new(bg.red, bg.green, bg.blue);
-			}
+			GdkRGBA rgba = background.handle;
+			attr = OS.pango_attr_background_new((short)(rgba.red * 0xFFFF),
+					(short)(rgba.green * 0xFFFF), (short)(rgba.blue * 0xFFFF));
 			OS.memmove (attribute, attr, PangoAttribute.sizeof);
 			attribute.start_index = byteStart;
 			attribute.end_index = byteEnd;
@@ -490,6 +466,7 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 	gc.checkGC(GC.FOREGROUND);
 	int length = text.length();
 	x += Math.min (indent, wrapIndent);
+	y += getScaledVerticalIndent();
 	boolean hasSelection = selectionStart <= selectionEnd && selectionStart != -1 && selectionEnd != -1;
 	GCData data = gc.data;
 	long /*int*/ cairo = data.cairo;
@@ -503,13 +480,8 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 		long /*int*/ iter = OS.pango_layout_get_iter(layout);
 		if (selectionBackground == null) selectionBackground = device.getSystemColor(SWT.COLOR_LIST_SELECTION);
 		Cairo.cairo_save(cairo);
-		if (GTK.GTK3) {
-			GdkRGBA rgba = selectionBackground.handleRGBA;
-			Cairo.cairo_set_source_rgba(cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
-		} else {
-			GdkColor color = selectionBackground.handle;
-			Cairo.cairo_set_source_rgba(cairo, (color.red & 0xFFFF) / (float)0xFFFF, (color.green & 0xFFFF) / (float)0xFFFF, (color.blue & 0xFFFF) / (float)0xFFFF, data.alpha / (float)0xFF);
-		}
+		GdkRGBA rgba = selectionBackground.handle;
+		Cairo.cairo_set_source_rgba(cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
 		int lineIndex = 0;
 		do {
 			int lineEnd;
@@ -580,7 +552,8 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 				Cairo.cairo_scale(cairo, -1,  1);
 				Cairo.cairo_translate(cairo, -2 * x - width(), 0);
 			}
-			drawWithCairo(gc, x, y, 0, C.strlen(ptr), fullSelection, selectionForeground, selectionBackground);
+			drawWithCairo(gc, x, y, 0, C.strlen(ptr), fullSelection, selectionForeground.handle,
+					selectionBackground.handle);
 			if ((data.style & SWT.MIRRORED) != 0) {
 				Cairo.cairo_restore(cairo);
 			}
@@ -596,7 +569,8 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 				Cairo.cairo_scale(cairo, -1,  1);
 				Cairo.cairo_translate(cairo, -2 * x - width(), 0);
 			}
-			drawWithCairo(gc, x, y, byteSelStart, byteSelEnd, fullSelection, selectionForeground, selectionBackground);
+			drawWithCairo(gc, x, y, byteSelStart, byteSelEnd, fullSelection, selectionForeground.handle,
+					selectionBackground.handle);
 			if ((data.style & SWT.MIRRORED) != 0) {
 				Cairo.cairo_restore(cairo);
 			}
@@ -607,7 +581,7 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 
 // Bug 477950: In order to support GTK2 and GTK3 colors simultaneously, this method's parameters
 // were modified to accept SWT Color objects instead of GdkColor structs.
-void drawWithCairo(GC gc, int x, int y, int start, int end, boolean fullSelection, Color fg, Color bg) {
+void drawWithCairo(GC gc, int x, int y, int start, int end, boolean fullSelection, GdkRGBA fg, GdkRGBA bg) {
 	GCData data = gc.data;
 	long /*int*/ cairo = data.cairo;
 	Cairo.cairo_save(cairo);
@@ -621,19 +595,11 @@ void drawWithCairo(GC gc, int x, int y, int start, int end, boolean fullSelectio
 	if (rgn != 0) {
 		GDK.gdk_cairo_region(cairo, rgn);
 		Cairo.cairo_clip(cairo);
-		if (GTK.GTK3) {
-			Cairo.cairo_set_source_rgba(cairo, bg.handleRGBA.red, bg.handleRGBA.green, bg.handleRGBA.blue, bg.handleRGBA.alpha);
-		} else {
-			Cairo.cairo_set_source_rgba(cairo, (bg.handle.red & 0xFFFF) / (float)0xFFFF, (bg.handle.green & 0xFFFF) / (float)0xFFFF, (bg.handle.blue & 0xFFFF) / (float)0xFFFF, data.alpha / (float)0xFF);
-		}
+		Cairo.cairo_set_source_rgba(cairo, bg.red, bg.green, bg.blue, bg.alpha);
 		Cairo.cairo_paint(cairo);
-		GDK.gdk_region_destroy(rgn);
-	}
-	if (GTK.GTK3) {
-		Cairo.cairo_set_source_rgba(cairo, fg.handleRGBA.red, fg.handleRGBA.green, fg.handleRGBA.blue, fg.handleRGBA.alpha);
-	} else {
-		Cairo.cairo_set_source_rgba(cairo, (fg.handle.red & 0xFFFF) / (float)0xFFFF, (fg.handle.green & 0xFFFF) / (float)0xFFFF, (fg.handle.blue & 0xFFFF) / (float)0xFFFF, data.alpha / (float)0xFF);
+		Cairo.cairo_region_destroy(rgn);
 	}
+	Cairo.cairo_set_source_rgba(cairo, fg.red, fg.green, fg.blue, fg.alpha);
 	Cairo.cairo_move_to(cairo, x, y);
 	OS.pango_layout_set_attributes(layout, selAttrList);
 	OS.pango_cairo_show_layout(cairo, layout);
@@ -642,9 +608,7 @@ void drawWithCairo(GC gc, int x, int y, int start, int end, boolean fullSelectio
 	Cairo.cairo_restore(cairo);
 }
 
-//Bug 477950: In order to support GTK2 and GTK3 colors simultaneously, this method's parameters
-//were modified to accept SWT Color objects instead of GdkColor structs.
-void drawBorder(GC gc, int x, int y, Color selectionColor) {
+void drawBorder(GC gc, int x, int y, GdkRGBA selectionColor) {
 	GCData data = gc.data;
 	long /*int*/ cairo = data.cairo;
 	long /*int*/ ptr = OS.pango_layout_get_text(layout);
@@ -668,21 +632,13 @@ void drawBorder(GC gc, int x, int y, Color selectionColor) {
 			if (rgn != 0) {
 				int[] nRects = new int[1];
 				long /*int*/[] rects = new long /*int*/[1];
-				Region.gdk_region_get_rectangles(rgn, rects, nRects);
-				GdkRectangle rect = new GdkRectangle();
+				Region.cairo_region_get_rectangles(rgn, rects, nRects);
+				cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
 				GdkRGBA colorRGBA = null;
-				GdkColor color = null;
-				if (GTK.GTK3) {
-					if (colorRGBA == null && style.borderColor != null) colorRGBA = style.borderColor.handleRGBA;
-					if (colorRGBA == null && selectionColor != null) colorRGBA = selectionColor.handleRGBA;
-					if (colorRGBA == null && style.foreground != null) colorRGBA = style.foreground.handleRGBA;
-					if (colorRGBA == null) colorRGBA = data.foregroundRGBA;
-				} else {
-					if (color == null && style.borderColor != null) color = style.borderColor.handle;
-					if (color == null && selectionColor != null) color = selectionColor.handle;
-					if (color == null && style.foreground != null) color = style.foreground.handle;
-					if (color == null) color = data.foreground;
-				}
+				if (colorRGBA == null && style.borderColor != null) colorRGBA = style.borderColor.handle;
+				if (colorRGBA == null && selectionColor != null) colorRGBA = selectionColor;
+				if (colorRGBA == null && style.foreground != null) colorRGBA = style.foreground.handle;
+				if (colorRGBA == null) colorRGBA = data.foregroundRGBA;
 				int width = 1;
 				float[] dashes = null;
 				switch (style.borderStyle) {
@@ -690,11 +646,7 @@ void drawBorder(GC gc, int x, int y, Color selectionColor) {
 					case SWT.BORDER_DASH: dashes = width != 0 ? GC.LINE_DASH : GC.LINE_DASH_ZERO; break;
 					case SWT.BORDER_DOT: dashes = width != 0 ? GC.LINE_DOT : GC.LINE_DOT_ZERO; break;
 				}
-				if (GTK.GTK3) {
-					Cairo.cairo_set_source_rgba(cairo, colorRGBA.red, colorRGBA.green, colorRGBA.blue, colorRGBA.alpha);
-				} else {
-					Cairo.cairo_set_source_rgba(cairo, (color.red & 0xFFFF) / (float)0xFFFF, (color.green & 0xFFFF) / (float)0xFFFF, (color.blue & 0xFFFF) / (float)0xFFFF, data.alpha / (float)0xFF);
-				}
+				Cairo.cairo_set_source_rgba(cairo, colorRGBA.red, colorRGBA.green, colorRGBA.blue, colorRGBA.alpha);
 				Cairo.cairo_set_line_width(cairo, width);
 				if (dashes != null) {
 					double[] cairoDashes = new double[dashes.length];
@@ -706,12 +658,12 @@ void drawBorder(GC gc, int x, int y, Color selectionColor) {
 					Cairo.cairo_set_dash(cairo, null, 0, 0);
 				}
 				for (int j=0; j<nRects[0]; j++) {
-					OS.memmove(rect, rects[0] + (j * GdkRectangle.sizeof), GdkRectangle.sizeof);
+					Cairo.memmove(rect, rects[0] + (j * cairo_rectangle_int_t.sizeof), cairo_rectangle_int_t.sizeof);
 					Cairo.cairo_rectangle(cairo, rect.x + 0.5, rect.y + 0.5, rect.width - 1, rect.height - 1);
 				}
 				Cairo.cairo_stroke(cairo);
 				if (rects[0] != 0) OS.g_free(rects[0]);
-				GDK.gdk_region_destroy(rgn);
+				Cairo.cairo_region_destroy(rgn);
 			}
 		}
 	}
@@ -789,7 +741,7 @@ public Rectangle getBounds() {
 	checkLayout();
 	Rectangle bounds = DPIUtil.autoScaleDown(getDevice(), getBoundsInPixels());
 	int lineCount = OS.pango_layout_get_line_count(layout);
-	int totalLineheight = 0;
+	int totalLineheight = getScaledVerticalIndent();
 	for (int i = 0; i < lineCount; i++) {
 		totalLineheight += this.getLineBounds(i).height + OS.PANGO_PIXELS(OS.pango_layout_get_spacing(layout));
 	}
@@ -809,7 +761,7 @@ Rectangle getBoundsInPixels() {
 		height = Math.max (height, DPIUtil.autoScaleUp(getDevice(), ascentInPoints + descentInPoints));
 	}
 	height += OS.PANGO_PIXELS(OS.pango_layout_get_spacing(layout));
-	return new Rectangle(0, 0, width, height);
+	return new Rectangle(0, 0, width, height + getScaledVerticalIndent());
 }
 
 /**
@@ -850,7 +802,7 @@ Rectangle getBoundsInPixels(int start, int end) {
 	int[] ranges = new int[]{byteStart, byteEnd};
 	long /*int*/ clipRegion = GDK.gdk_pango_layout_get_clip_region(layout, 0, 0, ranges, 1);
 	if (clipRegion == 0) return new Rectangle(0, 0, 0, 0);
-	GdkRectangle rect = new GdkRectangle();
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
 
 	/*
 	* Bug in Pango. The region returned by gdk_pango_layout_get_clip_region()
@@ -860,7 +812,7 @@ Rectangle getBoundsInPixels(int start, int end) {
 	PangoRectangle pangoRect = new PangoRectangle();
 	long /*int*/ iter = OS.pango_layout_get_iter(layout);
 	if (iter == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-	long /*int*/ linesRegion = GDK.gdk_region_new();
+	long /*int*/ linesRegion = Cairo.cairo_region_create();
 	if (linesRegion == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	int lineEnd = 0;
 	do {
@@ -875,16 +827,16 @@ Rectangle getBoundsInPixels(int start, int end) {
 		rect.y = OS.PANGO_PIXELS(pangoRect.y);
 		rect.width = OS.PANGO_PIXELS(pangoRect.width);
 		rect.height = OS.PANGO_PIXELS(pangoRect.height);
-		GDK.gdk_region_union_with_rect(linesRegion, rect);
+		Cairo.cairo_region_union_rectangle(linesRegion, rect);
 	} while (lineEnd + 1 <= byteEnd);
-	GDK.gdk_region_intersect(clipRegion, linesRegion);
-	GDK.gdk_region_destroy(linesRegion);
+	Cairo.cairo_region_intersect(clipRegion, linesRegion);
+	Cairo.cairo_region_destroy(linesRegion);
 	OS.pango_layout_iter_free(iter);
 
-	GDK.gdk_region_get_clipbox(clipRegion, rect);
-	GDK.gdk_region_destroy(clipRegion);
+	Cairo.cairo_region_get_extents(clipRegion, rect);
+	Cairo.cairo_region_destroy(clipRegion);
 	rect.x += Math.min (indent, wrapIndent);
-	return new Rectangle(rect.x, rect.y, rect.width, rect.height);
+	return new Rectangle(rect.x, rect.y, rect.width, rect.height + getScaledVerticalIndent());
 }
 
 /**
@@ -1201,7 +1153,7 @@ Point getLocationInPixels(int offset, boolean trailing) {
 		x = width() - x;
 	}
 	x += Math.min (indent, wrapIndent);
-	return new Point(x, OS.PANGO_PIXELS(y));
+	return new Point(x, OS.PANGO_PIXELS(y) + getScaledVerticalIndent());
 }
 
 /**
@@ -1552,6 +1504,34 @@ int getSpacingInPixels () {
 	return OS.PANGO_PIXELS(OS.pango_layout_get_spacing(layout));
 }
 
+/**
+ * Returns the vertical indent of the receiver.
+ *
+ * @return the vertical indent
+ *
+ * @exception SWTException <ul>
+ *    <li>ERROR_GRAPHIC_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.109
+ */
+public int getVerticalIndent () {
+	checkLayout();
+	return verticalIndentInPoints;
+}
+
+/**
+ * Returns the scaled vertical indent.
+ *
+ * @return the scaled vertical indent.
+ * @since 3.109
+ */
+private int getScaledVerticalIndent() {
+	if (verticalIndentInPoints == 0) {
+		return verticalIndentInPoints;
+	}
+	return DPIUtil.autoScaleUp(getDevice(), verticalIndentInPoints);
+}
+
 /**
  * Gets the style of the receiver at the specified character offset.
  *
@@ -1747,7 +1727,7 @@ public void setAlignment (int alignment) {
 }
 
 /**
- * Sets the ascent of the receiver. The ascent is distance in pixels
+ * Sets the ascent of the receiver. The ascent is distance in points
  * from the baseline to the top of the line and it is applied to all
  * lines. The default value is <code>-1</code> which means that the
  * ascent is calculated from the line fonts.
@@ -1773,7 +1753,7 @@ public void setAscent (int ascent) {
 }
 
 /**
- * Sets the descent of the receiver. The descent is distance in pixels
+ * Sets the descent of the receiver. The descent is distance in points
  * from the baseline to the bottom of the line and it is applied to all
  * lines. The default value is <code>-1</code> which means that the
  * descent is calculated from the line fonts.
@@ -1921,6 +1901,27 @@ void setSpacingInPixels (int spacing) {
 	OS.pango_layout_set_spacing(layout, spacing * OS.PANGO_SCALE);
 }
 
+/**
+ * Sets the vertical indent of the receiver.  The vertical indent
+ * is the space left before the first line.
+ *
+ * @param verticalIndent the new vertical indent
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_INVALID_ARGUMENT - if the vertical indent is negative</li>
+ * </ul>
+ * @exception SWTException <ul>
+ *    <li>ERROR_GRAPHIC_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.109
+ */
+public void setVerticalIndent (int verticalIndent) {
+	checkLayout();
+	if (verticalIndent < 0) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
+	if (this.verticalIndentInPoints == verticalIndent) return;
+	this.verticalIndentInPoints = verticalIndent;
+}
+
 /**
  * Sets the offsets of the receiver's text segments. Text segments are used to
  * override the default behavior of the bidirectional algorithm.
