@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -133,7 +133,6 @@ static GtkBorder getBorder (byte[] border, long /*int*/ handle, int defaultBorde
 
 @Override
 GdkRGBA getContextBackgroundGdkRGBA () {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (background != null && (state & BACKGROUND) != 0) {
 		return background;
 	}
@@ -273,24 +272,15 @@ void createHandle (int index) {
 	int bits = SWT.ARROW | SWT.TOGGLE | SWT.CHECK | SWT.RADIO | SWT.PUSH;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 	switch (style & bits) {
 		case SWT.ARROW:
-			if (GTK.GTK3) {
-				byte arrowType [] = GTK.GTK_NAMED_ICON_GO_UP;
-				if ((style & SWT.UP) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_UP;
-				if ((style & SWT.DOWN) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_DOWN;
-				if ((style & SWT.LEFT) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_PREVIOUS;
-				if ((style & SWT.RIGHT) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_NEXT;
-				arrowHandle = GTK.gtk_image_new_from_icon_name (arrowType, GTK.GTK_ICON_SIZE_MENU);
-			} else { //GTK2
-				int arrowType = GTK.GTK_ARROW_UP;
-				if ((style & SWT.UP) != 0) arrowType = GTK.GTK_ARROW_UP;
-				if ((style & SWT.DOWN) != 0) arrowType = GTK.GTK_ARROW_DOWN;
-	            if ((style & SWT.LEFT) != 0) arrowType = GTK.GTK_ARROW_LEFT;
-	            if ((style & SWT.RIGHT) != 0) arrowType = GTK.GTK_ARROW_RIGHT;
-	            arrowHandle = GTK.gtk_arrow_new (arrowType, GTK.GTK_SHADOW_OUT);
-			}
+			byte arrowType [] = GTK.GTK_NAMED_ICON_GO_UP;
+			if ((style & SWT.UP) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_UP;
+			if ((style & SWT.DOWN) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_DOWN;
+			if ((style & SWT.LEFT) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_PREVIOUS;
+			if ((style & SWT.RIGHT) != 0) arrowType = GTK.GTK_NAMED_ICON_GO_NEXT;
+			arrowHandle = GTK.gtk_image_new_from_icon_name (arrowType, GTK.GTK_ICON_SIZE_MENU);
 			if (arrowHandle == 0) error (SWT.ERROR_NO_HANDLES);
 
 			handle = GTK.gtk_button_new ();
@@ -333,11 +323,7 @@ void createHandle (int index) {
 	if ((style & SWT.ARROW) != 0) {
 		// Use gtk_button_set_image() on GTK3 to prevent icons from being
 		// trimmed with smaller sized buttons; see bug 528284.
-		if (GTK.GTK3) {
-			GTK.gtk_button_set_image(handle, arrowHandle);
-		} else {
-			GTK.gtk_container_add (handle, arrowHandle);
-		}
+		GTK.gtk_button_set_image(handle, arrowHandle);
 	} else {
 		boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 4);
 		if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
@@ -358,9 +344,7 @@ void createHandle (int index) {
 	if ((style & SWT.ARROW) != 0) return;
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription(defaultFont().handle);
-	}
+	setFontDescription(defaultFont().handle);
 	_setAlignment (style & (SWT.LEFT | SWT.CENTER | SWT.RIGHT));
 }
 
@@ -529,6 +513,28 @@ long /*int*/ gtk_clicked (long /*int*/ widget) {
 	return 0;
 }
 
+@Override
+long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+	/*
+	 * On GTK3.19+, widget are are shown with the default minimum size regardless of the
+	 * size of the fixed container. This causes 0x0 widgets to be visible but cannot be used.
+	 * The fix is to make the widget invisible to the user. Resizing widget later on to a larger size
+	 * makes the widget visible again in setBounds. See Bug 533469, Bug 531120.
+	 */
+	if (GTK.GTK_VERSION >= OS.VERSION (3, 20, 0) && (state & ZERO_WIDTH) != 0 && (state & ZERO_HEIGHT) != 0) {
+		if (GTK.gtk_widget_get_visible(widget)) GTK.gtk_widget_set_visible(widget, false);
+		// Button and display should not be disposed after hiding widget
+		if (isDisposed() || display == null || display.isDisposed()) error (SWT.ERROR_DEVICE_DISPOSED);
+	}
+	return super.gtk_draw(widget, cairo);
+}
+
+@Override
+boolean mustBeVisibleOnInitBounds() {
+	// Bug 540298: Button needs to be visible in order to gain focus.
+	return true;
+}
+
 @Override
 long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
 	long /*int*/ result = super.gtk_focus_in_event (widget, event);
@@ -644,23 +650,10 @@ public void removeSelectionListener (SelectionListener listener) {
 
 @Override
 void resizeHandle (int width, int height) {
-	if (GTK.GTK3) {
-		if ((style & (SWT.CHECK | SWT.RADIO)) != 0 && (style & SWT.WRAP) == 0) {
-			OS.swt_fixed_resize (GTK.gtk_widget_get_parent (topHandle()), topHandle(), width, height);
-		} else {
-			super.resizeHandle(width, height);
-		}
+	if ((style & (SWT.CHECK | SWT.RADIO)) != 0 && (style & SWT.WRAP) == 0) {
+		OS.swt_fixed_resize (GTK.gtk_widget_get_parent (topHandle()), topHandle(), width, height);
 	} else {
-		super.resizeHandle (width, height);
-		/*
-		* Feature in GTK, GtkCheckButton and GtkRadioButton allocate
-		* only the minimum size necessary for its child. This causes the child
-		* alignment to fail. The fix is to set the child size to the size
-		* of the button.
-		*/
-		if ((style & (SWT.CHECK | SWT.RADIO)) != 0) {
-			GTK.gtk_widget_set_size_request (boxHandle, width, -1);
-		}
+		super.resizeHandle(width, height);
 	}
 }
 
@@ -716,25 +709,14 @@ void _setAlignment (int alignment) {
 		style &= ~(SWT.UP | SWT.DOWN | SWT.LEFT | SWT.RIGHT);
 		style |= alignment & (SWT.UP | SWT.DOWN | SWT.LEFT | SWT.RIGHT);
 		boolean isRTL = (style & SWT.RIGHT_TO_LEFT) != 0;
-		if (GTK.GTK3) {
-			byte arrowType [] = GTK.GTK_NAMED_ICON_GO_UP;
-			switch (alignment) {
-				case SWT.UP: arrowType = GTK.GTK_NAMED_ICON_GO_UP; break;
-				case SWT.DOWN: arrowType = GTK.GTK_NAMED_ICON_GO_DOWN; break;
-				case SWT.LEFT: arrowType = isRTL ? GTK.GTK_NAMED_ICON_GO_NEXT : GTK.GTK_NAMED_ICON_GO_PREVIOUS; break;
-				case SWT.RIGHT: arrowType = isRTL ? GTK.GTK_NAMED_ICON_GO_PREVIOUS : GTK.GTK_NAMED_ICON_GO_NEXT; break;
-			}
-			GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU);
-		} else { //GTK2
-			int arrowType = GTK.GTK_ARROW_UP;
-			switch (alignment) {
-				case SWT.UP: arrowType = GTK.GTK_ARROW_UP; break;
-				case SWT.DOWN: arrowType = GTK.GTK_ARROW_DOWN; break;
-				case SWT.LEFT: arrowType = isRTL ? GTK.GTK_ARROW_RIGHT : GTK.GTK_ARROW_LEFT; break;
-				case SWT.RIGHT: arrowType = isRTL ? GTK.GTK_ARROW_LEFT : GTK.GTK_ARROW_RIGHT; break;
-			}
-			GTK.gtk_arrow_set (arrowHandle, arrowType, GTK.GTK_SHADOW_OUT);
+		byte arrowType [] = GTK.GTK_NAMED_ICON_GO_UP;
+		switch (alignment) {
+			case SWT.UP: arrowType = GTK.GTK_NAMED_ICON_GO_UP; break;
+			case SWT.DOWN: arrowType = GTK.GTK_NAMED_ICON_GO_DOWN; break;
+			case SWT.LEFT: arrowType = isRTL ? GTK.GTK_NAMED_ICON_GO_NEXT : GTK.GTK_NAMED_ICON_GO_PREVIOUS; break;
+			case SWT.RIGHT: arrowType = isRTL ? GTK.GTK_NAMED_ICON_GO_PREVIOUS : GTK.GTK_NAMED_ICON_GO_NEXT; break;
 		}
+		GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU);
 		return;
 	}
 	if ((alignment & (SWT.LEFT | SWT.RIGHT | SWT.CENTER)) == 0) return;
@@ -751,10 +733,8 @@ void _setAlignment (int alignment) {
 			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_START);
 			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_START);
 		} else {
-			if (GTK.GTK3) {
-				GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-				GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
-			}
+			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 		}
 
 		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
@@ -782,10 +762,8 @@ void _setAlignment (int alignment) {
 			}
 
 		} else {
-			if (GTK.GTK3) {
-				GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-				GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
-			}
+			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 
 			if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0))  {
 				gtk_label_set_align(labelHandle,0.5f,0.5f);
@@ -803,10 +781,8 @@ void _setAlignment (int alignment) {
 			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_END);
 			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_END);
 		} else {
-			if (GTK.GTK3) {
-				GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-				GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
-			}
+			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 		}
 
 		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0))  {
@@ -823,8 +799,6 @@ void _setAlignment (int alignment) {
 
 @Override
 void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
-
 	background = rgba;
 	//Pre GTK 3.10 doesn't handle CSS background color very well for GTK Check/Radio button.
 	// 3.10.3 as it was the latest to affect theming in button.
@@ -845,15 +819,6 @@ void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rg
 	gtk_css_provider_load_from_css (context, finalCss);
 }
 
-@Override
-void setBackgroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setBackgroundGdkColor (color);
-	setBackgroundGdkColor(fixedHandle, color);
-	if (labelHandle != 0) setBackgroundGdkColor(labelHandle, color);
-	if (imageHandle != 0) setBackgroundGdkColor(imageHandle, color);
-}
-
 @Override
 int setBounds (int x, int y, int width, int height, boolean move, boolean resize) {
 	/*
@@ -943,7 +908,6 @@ boolean setRadioSelection (boolean value) {
 
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	super.setForegroundGdkRGBA(rgba);
 	setForegroundGdkRGBA (fixedHandle, rgba);
 	if (labelHandle != 0) setForegroundGdkRGBA (labelHandle, rgba);
@@ -961,18 +925,8 @@ void setForegroundGdkRGBA (GdkRGBA rgba) {
 	}
 }
 
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setForegroundGdkColor (color);
-	setForegroundColor (fixedHandle, color);
-	if (labelHandle != 0) setForegroundColor (labelHandle, color);
-	if (imageHandle != 0) setForegroundColor (imageHandle, color);
-}
-
 @Override
 void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
 		super.setForegroundGdkRGBA(handle, rgba);
 		return;
@@ -994,7 +948,6 @@ void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
 }
 
 private void gtk_swt_set_border_color (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	String css_string = "* {\n";
 	if (rgba != null) {
 		String css_color = display.gtk_rgba_to_css_string (rgba);
@@ -1070,9 +1023,9 @@ public void setImage (Image image) {
 		imageList = new ImageList ();
 		int imageIndex = imageList.add (image);
 		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf(imageHandle, pixbuf);
+		gtk_image_set_from_gicon(imageHandle, pixbuf);
 	} else {
-		gtk_image_set_from_pixbuf (imageHandle, 0);
+		gtk_image_set_from_gicon (imageHandle, 0);
 	}
 	this.image = image;
 	updateWidgetsVisibility();
@@ -1088,19 +1041,10 @@ void setOrientation (boolean create) {
 		if (labelHandle != 0) GTK.gtk_widget_set_direction (labelHandle, dir);
 		if (imageHandle != 0) GTK.gtk_widget_set_direction (imageHandle, dir);
 		if (arrowHandle != 0) {
-			if (GTK.GTK3) {
-				byte arrowType [] = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_NAMED_ICON_GO_NEXT : GTK.GTK_NAMED_ICON_GO_PREVIOUS;
-				switch (style & (SWT.LEFT | SWT.RIGHT)) {
-					case SWT.LEFT: GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU); break;
-					case SWT.RIGHT: GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU); break;
-				}
-			} else { //GTK2
-				int arrowDir = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_ARROW_RIGHT : GTK.GTK_ARROW_LEFT;
-				switch (style & (SWT.LEFT | SWT.RIGHT)) {
-					case SWT.LEFT: GTK.gtk_arrow_set (arrowHandle, arrowDir, GTK.GTK_SHADOW_OUT); break;
-					case SWT.RIGHT: GTK.gtk_arrow_set (arrowHandle, arrowDir, GTK.GTK_SHADOW_OUT); break;
-				}
-
+			byte arrowType [] = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_NAMED_ICON_GO_NEXT : GTK.GTK_NAMED_ICON_GO_PREVIOUS;
+			switch (style & (SWT.LEFT | SWT.RIGHT)) {
+				case SWT.LEFT: GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU); break;
+				case SWT.RIGHT: GTK.gtk_image_set_from_icon_name (arrowHandle, arrowType, GTK.GTK_ICON_SIZE_MENU); break;
 			}
 		}
 	}
