@@ -89,20 +89,24 @@ public class DateTime extends Composite {
 	Listener popupListener, popupFilter;
 
 	Point prefferedSize;
+	Locale locale;
 
 	/** Used when SWT.DROP_DOWN is set */
 	Listener mouseEventListener;
 
-	static final String DEFAULT_SHORT_DATE_FORMAT = "MM/YYYY";
-	static final String DEFAULT_MEDIUM_DATE_FORMAT = "MM/DD/YYYY";
-	static final String DEFAULT_LONG_DATE_FORMAT = "MM/DD/YYYY";
-	static final String DEFAULT_SHORT_TIME_FORMAT = "HH:MM AM";
-	static final String DEFAULT_MEDIUM_TIME_FORMAT = "HH:MM:SS AM";
-	static final String DEFAULT_LONG_TIME_FORMAT = "HH:MM:SS AM";
+	/*
+	 * Used for easier access to format pattern of DATE and TIME.
+	 * See https://docs.oracle.com/javase/7/docs/api/java/text/SimpleDateFormat.html
+	 */
+	static final String DEFAULT_SHORT_DATE_FORMAT = "dd/MM/yy";
+	static final String DEFAULT_MEDIUM_DATE_FORMAT = "d-MMM-yyyy";
+	static final String DEFAULT_LONG_DATE_FORMAT = "MMMM d, yyyy";
+	static final String DEFAULT_SHORT_TIME_FORMAT = "h:mm a";
+	static final String DEFAULT_MEDIUM_TIME_FORMAT = "h:mm:ss a";
+	static final String DEFAULT_LONG_TIME_FORMAT = "h:mm:ss z a";
 	static final int MIN_YEAR = 1752; // Gregorian switchover in North America: September 19, 1752
 	static final int MAX_YEAR = 9999;
 	static final int SPACE_FOR_CURSOR = 1;
-	static final int GTK2_MANUAL_BORDER_PADDING = 2;
 
 	private int mdYear;
 
@@ -170,13 +174,11 @@ public DateTime (Composite parent, int style) {
 
 void createText() {
 	String property = System.getProperty("swt.datetime.locale");
-	Locale locale;
 	if (property == null || property.isEmpty()) {
 		locale = Locale.getDefault();
 	} else {
 		locale = Locale.forLanguageTag(property);
 	}
-
 	dateFormat = getFormat(locale, style);
 	dateFormat.setLenient(false);
 	calendar = Calendar.getInstance(locale);
@@ -212,11 +214,6 @@ static int checkStyle (int style) {
 	*/
 	style &= ~(SWT.H_SCROLL | SWT.V_SCROLL);
 
-	//Workaround. Right_to_left is buggy on gtk2. Only allow on gtk3 onwards
-	if (!GTK.GTK3 && isDateWithDropDownButton (style)) {
-		style &= ~(SWT.RIGHT_TO_LEFT);
-	}
-
 	style = checkBits (style, SWT.DATE, SWT.TIME, SWT.CALENDAR, 0, 0, 0);
 	if ((style & SWT.DATE) == 0) style &=~ SWT.DROP_DOWN;
 	return checkBits (style, SWT.MEDIUM, SWT.SHORT, SWT.LONG, 0, 0, 0);
@@ -259,13 +256,58 @@ protected void checkSubclass () {
 	if (!isValidSubclass ()) error (SWT.ERROR_INVALID_SUBCLASS);
 }
 
+/**
+ * Compute the native text entry size when the formatted text inside the entry
+ * is at the longest length possible. i.e. Assume DATE/HOUR field to be double digit,
+ * MONTH field for SWT.DATE | SWT.LONG is the longest text.
+ *
+ * @param wHint
+ * @param hHint
+ * @param changed
+ * @return text entry size to hold the longest possible formatted text.
+ */
+Point computeMaxTextSize (int wHint, int hHint, boolean changed) {
+	String currentText = getFormattedString();
+	String formatPattern = getComputeSizeString(style);
+
+	switch (formatPattern) {
+		case DEFAULT_MEDIUM_DATE_FORMAT:
+			// Make the DATE field a double digit
+			String longDateText = currentText.replaceFirst("\\d{1,2}", "00");
+			setText(longDateText);
+			break;
+		case DEFAULT_LONG_DATE_FORMAT:
+			// Make the MONTH field the longest length possible, the DATE field a double digit.
+			Set<String> months = calendar.getDisplayNames(Calendar.MONTH, Calendar.LONG, locale).keySet();
+			String longestMonth = Collections.max(months, (s1, s2) -> s1.length() - s2.length()); // Probably September
+			String doubleDigitDate = currentText.replaceFirst("\\d{1,2}", "00");
+			String longText = doubleDigitDate.replaceFirst("[^\\s]+", longestMonth);
+			setText(longText);
+			break;
+		case DEFAULT_SHORT_TIME_FORMAT:
+		case DEFAULT_MEDIUM_TIME_FORMAT:
+		case DEFAULT_LONG_TIME_FORMAT:
+			// Make the HOUR field a double digit
+			String longTimeText = currentText.replaceFirst("\\d{1,2}", "00");
+			setText(longTimeText);
+			break;
+		default:
+			// Fixed length for DEFAULT_SHORT_DATE_FORMAT, no need to adjust text length.
+	}
+
+	Point textSize = computeNativeSize (textEntryHandle, wHint, hHint, changed);
+	// Change the text back to match the current calendar
+	updateControl();
+	return textSize;
+}
+
 @Override
 Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	checkWidget ();
 
 	int width = 0, height = 0;
 	//For Date and Time, we cache the preffered size as there is no need to recompute it.
-	if (!changed && (isDate () || isTime ()) && GTK.GTK3 && prefferedSize != null) {
+	if (!changed && (isDate () || isTime ()) && prefferedSize != null) {
 		width = (wHint != SWT.DEFAULT) ? wHint : prefferedSize.x;
 		height= (hHint != SWT.DEFAULT) ? hHint : prefferedSize.y;
 		return new Point (width,height);
@@ -277,21 +319,21 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 			width = size.x;
 			height = size.y;
 		} else {
-			Point textSize = computeNativeSize (textEntryHandle, wHint, hHint, changed);
+			/*
+			 * Bug 538612: Computing the native size for textEntry when the current text
+			 * is not the longest length possible causes sizing issues when the entry text
+			 * is changed. Fix is to always allocate enough size to hold the longest possible
+			 * formatted text.
+			 */
+			Point textSize = computeMaxTextSize (wHint, hHint, changed);
 			Rectangle trim = computeTrimInPixels (0,0, textSize.x,textSize.y);
 			if (isDateWithDropDownButton ()){
 				Point buttonSize = down.computeSizeInPixels (SWT.DEFAULT, SWT.DEFAULT, changed);
 				width = trim.width + buttonSize.x;
 				height = Math.max (trim.height, buttonSize.y);
 			} else if (isDate () || isTime ()) {
-				if (GTK.GTK3) {
-					width = trim.width;
-					height = trim.height;
-				} else
-				{ //in GTK2, spin button looks broken if you incorperate the trim. Thus do not compute trim.
-					width = textSize.x;
-					height = textSize.y;
-				}
+				width = trim.width;
+				height = trim.height;
 			}
 		}
 	}
@@ -301,7 +343,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	if (hHint != SWT.DEFAULT) height = hHint;
 	int borderWidth = getBorderWidthInPixels ();
 
-	if (prefferedSize == null && (isDateWithDropDownButton () && GTK.GTK3)) {
+	if (prefferedSize == null && isDateWithDropDownButton ()) {
 		prefferedSize = new Point (width + 2*borderWidth, height+ 2*borderWidth);
 		return prefferedSize;
 	} else {
@@ -318,40 +360,27 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	checkWidget ();
 	Rectangle trim = super.computeTrimInPixels (x, y, width, height);
 	int xborder = 0, yborder = 0;
-		if (GTK.GTK3) {
-			GtkBorder tmp = new GtkBorder ();
-			long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
+		GtkBorder tmp = new GtkBorder ();
+		long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
+		if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
+			GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
+		} else {
+			GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
+		}
+		trim.x -= tmp.left;
+		trim.y -= tmp.top;
+		trim.width += tmp.left + tmp.right;
+		trim.height += tmp.top + tmp.bottom;
+		if ((style & SWT.BORDER) != 0) {
 			if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-				GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
+				GTK.gtk_style_context_get_border (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
 			} else {
-				GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
+				GTK.gtk_style_context_get_border (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
 			}
 			trim.x -= tmp.left;
 			trim.y -= tmp.top;
 			trim.width += tmp.left + tmp.right;
 			trim.height += tmp.top + tmp.bottom;
-			if ((style & SWT.BORDER) != 0) {
-				if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-					GTK.gtk_style_context_get_border (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
-				} else {
-					GTK.gtk_style_context_get_border (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
-				}
-				trim.x -= tmp.left;
-				trim.y -= tmp.top;
-				trim.width += tmp.left + tmp.right;
-				trim.height += tmp.top + tmp.bottom;
-			}
-		} else {
-			if ((style & SWT.BORDER) != 0) {
-				Point thickness = getThickness (textEntryHandle);
-				xborder += thickness.x;
-				yborder += thickness.y;
-			}
-			GtkBorder innerBorder = Display.getEntryInnerBorder (textEntryHandle);
-			trim.x -= innerBorder.left;
-			trim.y -= innerBorder.top;
-			trim.width += innerBorder.left + innerBorder.right;
-			trim.height += innerBorder.top + innerBorder.bottom;
 		}
 		trim.x -= xborder;
 		trim.y -= yborder;
@@ -396,7 +425,7 @@ void createHandle () {
 private void createHandleForFixed () {
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 }
 
 private void createHandleForCalendar () {
@@ -436,9 +465,7 @@ private void createHandleForDateWithDropDown () {
 
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription (defaultFont ().handle);
-	}
+	setFontDescription (defaultFont ().handle);
 }
 
 private void createHandleForDateTime () {
@@ -670,16 +697,6 @@ private void hideDropDownCalendar () {
 	return;
 }
 
-@Override
-GdkColor getBackgroundGdkColor () {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	if (isCalendar ()) {
-		return getBaseGdkColor ();
-	} else {
-		return super.getBackgroundGdkColor ();
-	}
-}
-
 String getComputeSizeString (int style) {
 	if ((style & SWT.DATE) != 0) {
 		return (style & SWT.SHORT) != 0 ? DEFAULT_SHORT_DATE_FORMAT : (style & SWT.LONG) != 0 ? DEFAULT_LONG_DATE_FORMAT : DEFAULT_MEDIUM_DATE_FORMAT;
@@ -988,11 +1005,6 @@ private boolean isDateWithDropDownButton () {
 	return ((style & SWT.DROP_DOWN) != 0 && (style & SWT.DATE) != 0);
 }
 
-static private boolean isDateWithDropDownButton (int style) {
-	return ((style & SWT.DROP_DOWN) != 0 && (style & SWT.DATE) != 0);
-}
-
-
 private boolean isDate () {
 	return ((style & SWT.DATE) != 0);
 }
@@ -1348,28 +1360,12 @@ void sendSelectionEvent () {
 @Override
 public void setBackground (Color color) {
 	super.setBackground (color);
-	if (!GTK.GTK3) {
-		if ((isCalendar ()) && color == null) {
-			GTK.gtk_widget_modify_base (containerHandle, 0, null);
-		}
-	}
 	bg = color;
 	if (popupCalendar != null) popupCalendar.setBackground (color);
 }
 
-@Override
-void setBackgroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	if (isCalendar ()) {
-		GTK.gtk_widget_modify_base (containerHandle, 0, color);
-	} else {
-		super.setBackgroundGdkColor (color);
-	}
-}
-
 @Override
 void setBackgroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	super.setBackgroundGdkRGBA(rgba);
 	if (calendarHandle != 0) {
 		setBackgroundGdkRGBA (calendarHandle, rgba);
@@ -1380,8 +1376,6 @@ void setBackgroundGdkRGBA (GdkRGBA rgba) {
 
 @Override
 void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
-
 	// We need to override here because DateTime widgets use "background" instead of
 	// "background-color" as their CSS property.
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
@@ -1417,15 +1411,8 @@ public void setFont (Font font) {
 	redraw ();
 }
 
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	setForegroundColor (containerHandle, color, false);
-}
-
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	setForegroundGdkRGBA (containerHandle, rgba);
 }
 
@@ -1686,7 +1673,7 @@ public void setYear (int year) {
 void setBoundsInPixels (int x, int y, int width, int height) {
 
 	//Date with Drop down is in container. Needs extra handling.
-	if (isDateWithDropDownButton () && GTK.GTK3) {
+	if (isDateWithDropDownButton ()) {
 		GtkRequisition requisition = new GtkRequisition ();
 		GTK.gtk_widget_get_preferred_size (textEntryHandle, null, requisition);
 		int oldHeight = requisition.height; //Entry should not expand vertically. It is single liner.
@@ -1709,7 +1696,7 @@ void setBoundsInPixels (int x, int y, int width, int height) {
 	 * native height.
 	 */
 	int fixedGtkVersion = OS.VERSION (3, 14, 2);
-	if (isCalendar () && GTK.GTK3 && (GTK.GTK_VERSION < fixedGtkVersion)) {
+	if (isCalendar () && (GTK.GTK_VERSION < fixedGtkVersion)) {
 			int calendarPrefferedVerticalSize = computeSizeInPixels (SWT.DEFAULT, SWT.DEFAULT, true).y;
 			if (height > calendarPrefferedVerticalSize) {
 				height = calendarPrefferedVerticalSize;
@@ -1746,22 +1733,15 @@ private void setDropDownButtonSize () {
  * @return GtkBorder object that holds the padding values.
  */
 GtkBorder getGtkBorderPadding () {
-	if (GTK.GTK3) {
-		//In Gtk3, acquire border.
-		GtkBorder gtkBorderPadding = new GtkBorder ();
-		long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
-		if (GTK.GTK_VERSION < OS.VERSION(3, 18 , 0)) {
-			GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, gtkBorderPadding);
-		} else {
-			GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), gtkBorderPadding);
-		}
-		return gtkBorderPadding;
+	//In Gtk3, acquire border.
+	GtkBorder gtkBorderPadding = new GtkBorder ();
+	long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
+	if (GTK.GTK_VERSION < OS.VERSION(3, 18 , 0)) {
+		GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, gtkBorderPadding);
 	} else {
-		//in GTK2 hard code the padding
-		GtkBorder padding = new GtkBorder ();
-		padding.bottom = padding.top = padding.left = padding.right = GTK2_MANUAL_BORDER_PADDING;
-		return padding;
+		GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), gtkBorderPadding);
 	}
+	return gtkBorderPadding;
 }
 
 boolean onNumberKeyInput(int key) {
@@ -1859,7 +1839,7 @@ void register () {
 
 @Override
 GdkRGBA defaultBackground () {
-	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handleRGBA;
+	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handle;
 }
 
 @Override
@@ -1874,6 +1854,13 @@ int getArrow(long /*int*/ widget) {
 	int adj_value = (int) GTK.gtk_adjustment_get_value(GTK.gtk_spin_button_get_adjustment(widget));
 	int new_value = 0;
 	if (isDate()) {
+		if ((style & SWT.LONG) != 0) {
+			if (adj_value == 0) {
+				return 0;
+			} else {
+				return adj_value > 0 ? SWT.ARROW_UP : SWT.ARROW_DOWN;
+			}
+		}
 		FieldPosition firstField = getNextField(null);
 		new_value = calendar.get(getCalendarField(firstField));
 	} else if (isTime()) {
@@ -2116,11 +2103,11 @@ long /*int*/ gtk_output (long /*int*/ widget) {
 	}
 	int arrowType = getArrow(widget);
 	switch (arrowType) {
-	case SWT.ARROW_UP: // Gtk2 arrow up. Gtk3 "+" button.
+	case SWT.ARROW_UP: // Gtk3 "+" button.
 		commitData();
 		incrementField(+1);
 		break;
-	case SWT.ARROW_DOWN: // Gtk2 arrow down. Gtk3 "-" button.
+	case SWT.ARROW_DOWN: // Gtk3 "-" button.
 		commitData();
 		incrementField(-1);
 		break;
