@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -203,7 +203,7 @@ void createHandle (int index) {
 	state |= HANDLE;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 	scrolledHandle = GTK.gtk_scrolled_window_new (0, 0);
 	if (scrolledHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	/*
@@ -246,9 +246,7 @@ void createHandle (int index) {
 	}
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription(defaultFont().handle);
-	}
+	setFontDescription(defaultFont().handle);
 }
 
 @Override
@@ -269,8 +267,8 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	 * So if the height is returned as zero calculate the table height
 	 * based on the number of items in the table
 	 */
-	 if (GTK.GTK3 && size.y == 0 && hHint == SWT.DEFAULT) {
-	 size.y = getItemCount() * getItemHeightInPixels();
+	 if (size.y == 0 && hHint == SWT.DEFAULT) {
+		 size.y = getItemCount() * getItemHeightInPixels();
 	 }
 
 	 /*
@@ -287,7 +285,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 
 @Override
 GdkRGBA defaultBackground () {
-	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handleRGBA;
+	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handle;
 }
 
 @Override
@@ -447,12 +445,6 @@ long /*int*/ eventWindow () {
 	return paintWindow ();
 }
 
-@Override
-GdkColor getBackgroundGdkColor () {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	return getBaseGdkColor ();
-}
-
 /**
  * Returns the zero-relative index of the item which currently
  * has the focus in the receiver, or -1 if no item has focus.
@@ -476,12 +468,6 @@ public int getFocusIndex () {
 	return index [0];
 }
 
-@Override
-GdkColor getForegroundGdkColor () {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	return getTextColor ();
-}
-
 /**
  * Returns the item at the given, zero-relative index in the
  * receiver. Throws an exception if the index is out of range.
@@ -554,11 +540,9 @@ int getItemHeightInPixels () {
 		int [] w = new int [1], h = new int [1];
 		GTK.gtk_tree_view_column_cell_get_size (column, null, null, null, w, h);
 		int height = h [0];
-		if (GTK.GTK3) {
-			long /*int*/ textRenderer = getTextRenderer (column);
-			if (textRenderer != 0) GTK.gtk_cell_renderer_get_preferred_height_for_width (textRenderer, handle, 0, h, null);
-			height += h [0];
-		}
+		long /*int*/ textRenderer = getTextRenderer (column);
+		if (textRenderer != 0) GTK.gtk_cell_renderer_get_preferred_height_for_width (textRenderer, handle, 0, h, null);
+		height += h [0];
 		return height;
 	} else {
 		int height = 0;
@@ -567,14 +551,10 @@ int getItemHeightInPixels () {
 		GTK.gtk_tree_view_column_cell_set_cell_data (column, modelHandle, iter, false, false);
 		int [] w = new int [1], h = new int [1];
 		GTK.gtk_tree_view_column_cell_get_size (column, null, null, null, w, h);
-		if (GTK.GTK3) {
-			long /*int*/ textRenderer = getTextRenderer (column);
-			int [] ypad = new int[1];
-			if (textRenderer != 0) GTK.gtk_cell_renderer_get_padding(textRenderer, null, ypad);
-			height = h [0] + ypad [0];
-		} else {
-			height = h [0];
-		}
+		long /*int*/ textRenderer = getTextRenderer (column);
+		int [] ypad = new int[1];
+		if (textRenderer != 0) GTK.gtk_cell_renderer_get_padding(textRenderer, null, ypad);
+		height = h [0] + ypad [0];
 		OS.g_free (iter);
 		return height;
 	}
@@ -777,14 +757,12 @@ public int getTopIndex () {
 	 * if setTopIndex() has been called and the widget has not been scrolled
 	 * using the UI. Otherwise, fetch topIndex using GtkTreeView API.
 	 */
-	long /*int*/ vAdjustment;
-	if (GTK.GTK3) {
-		vAdjustment = GTK.gtk_scrollable_get_vadjustment (handle);
-	} else {
-		vAdjustment = GTK.gtk_tree_view_get_vadjustment (handle);
-	}
+	long /*int*/ vAdjustment = GTK.gtk_scrollable_get_vadjustment (handle);
 	currentAdjustment = GTK.gtk_adjustment_get_value (vAdjustment);
 	if (cachedAdjustment == currentAdjustment) {
+		if (Device.DEBUG) {
+			System.out.println("Using the cached GtkAdjustment, topIndex is " + topIndex);
+		}
 		return topIndex;
 	} else {
 		long /*int*/ [] path = new long /*int*/ [1];
@@ -795,6 +773,9 @@ public int getTopIndex () {
 		int[] index = new int [1];
 		if (indices != 0) C.memmove (index, indices, 4);
 		GTK.gtk_tree_path_free (path [0]);
+		if (Device.DEBUG) {
+			System.out.println("Fetching the top index from GTK, topIndex is " + index[0]);
+		}
 		return index [0];
 	}
 }
@@ -805,26 +786,6 @@ long /*int*/ gtk_changed (long /*int*/ widget) {
 	return 0;
 }
 
-@Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
-	switch (GDK.GDK_EVENT_TYPE (gdkEvent)) {
-		case GDK.GDK_EXPOSE: {
-			/*
-			* Bug in GTK. SWT connects the expose-event 'after' the default
-			* handler of the signal. If the tree has no children, then GTK
-			* sends expose signal only 'before' the default signal handler.
-			* The fix is to detect this case in 'event_after' and send the
-			* expose event.
-			*/
-			if (GTK.gtk_tree_model_iter_n_children (modelHandle, 0) == 0) {
-				gtk_expose_event (widget, gdkEvent);
-			}
-			break;
-		}
-	}
-	return super.gtk_event_after (widget, gdkEvent);
-}
-
 @Override
 long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
 	long /*int*/ result = super.gtk_button_press_event (widget, event);
@@ -1095,6 +1056,7 @@ public boolean isSelected (int index) {
 @Override
 long /*int*/ paintWindow () {
 	GTK.gtk_widget_realize (handle);
+	// TODO: this function has been removed on GTK4
 	return GTK.gtk_tree_view_get_bin_window (handle);
 }
 
@@ -1439,13 +1401,6 @@ void selectFocusIndex (int index) {
 	OS.g_free (iter);
 }
 
-@Override
-void setBackgroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setBackgroundGdkColor (color);
-	GTK.gtk_widget_modify_base (handle, 0, color);
-}
-
 @Override
 int setBounds (int x, int y, int width, int height, boolean move, boolean resize) {
 	int result = super.setBounds (x, y, width, height, move, resize);
@@ -1527,7 +1482,6 @@ public void setItems (String... items) {
 
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (GTK.GTK_VERSION >= OS.VERSION (3, 14, 0)) {
 		GdkRGBA toSet = rgba == null ? display.COLOR_LIST_FOREGROUND_RGBA : rgba;
 		setForegroundGdkRGBA (handle, toSet);
@@ -1536,12 +1490,6 @@ void setForegroundGdkRGBA (GdkRGBA rgba) {
 	}
 }
 
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	setForegroundColor (handle, color, false);
-}
-
 /**
  * Selects the item at the given zero-relative index in the receiver.
  * If the item at the index was already selected, it remains selected.
@@ -1711,12 +1659,7 @@ public void setTopIndex (int index) {
 	 * Use gtk_tree_view_get_view_get_vadjustment for GTK2, GtkScrollable
 	 * doesn't exist on GTK2.
 	 */
-	long /*int*/ vAdjustment;
-	if (GTK.GTK3) {
-		vAdjustment = GTK.gtk_scrollable_get_vadjustment (handle);
-	} else {
-		vAdjustment = GTK.gtk_tree_view_get_vadjustment (handle);
-	}
+	long /*int*/ vAdjustment = GTK.gtk_scrollable_get_vadjustment (handle);
 	cachedAdjustment = GTK.gtk_adjustment_get_value (vAdjustment);
 	topIndex = index;
 	/*
