@@ -247,12 +247,10 @@ void register () {
 
 @Override
 void release (boolean destroy) {
-	if (GTK.GTK3) {
-		//Since controls are now nested under the tabItem,
-		//tabItem is responsible for it's release.
-		if (control != null && !control.isDisposed ()) {
-			control.release (destroy);
-		}
+	//Since controls are now nested under the tabItem,
+	//tabItem is responsible for it's release.
+	if (control != null && !control.isDisposed ()) {
+		control.release (destroy);
 	}
 	super.release (destroy);
 }
@@ -295,7 +293,7 @@ public void setControl (Control control) {
 		if (control.parent != parent) error (SWT.ERROR_INVALID_PARENT);
 	}
 
-	if (control != null && GTK.GTK3) {
+	if (control != null) {
 		// To understand why we reparent, see implementation note about bug 454936 at the start of TabFolder.
 		Control.gtk_widget_reparent (control, pageHandle);
 	}
@@ -328,20 +326,11 @@ void setFontDescription (long /*int*/ font) {
 }
 
 void setForegroundRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	setForegroundGdkRGBA (labelHandle, rgba);
 	setForegroundGdkRGBA (imageHandle, rgba);
 }
 
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	/* Don't set the color in vbox handle (it doesn't draw) */
-	setForegroundColor (labelHandle, color, false);
-	setForegroundColor (imageHandle, color, false);
-}
-
 void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	GdkRGBA toSet = new GdkRGBA();
 	if (rgba != null) {
 		toSet = rgba;
@@ -383,10 +372,10 @@ public void setImage (Image image) {
 			imageList.put (imageIndex, image);
 		}
 		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf (imageHandle, pixbuf);
+		gtk_image_set_from_gicon (imageHandle, pixbuf);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
-		gtk_image_set_from_pixbuf (imageHandle, 0);
+		gtk_image_set_from_gicon (imageHandle, 0);
 		GTK.gtk_widget_hide (imageHandle);
 	}
 }
