@@ -443,13 +443,12 @@ public void pack () {
 	checkWidget();
 	int width = 0;
 	if (buttonHandle != 0) {
+		boolean hideHeader = !GTK.gtk_widget_get_visible(buttonHandle);
 		GtkRequisition requisition = new GtkRequisition ();
-		if (GTK.GTK3) {
-			GTK.gtk_widget_show(buttonHandle);
-			gtk_widget_get_preferred_size (buttonHandle, requisition);
+		GTK.gtk_widget_show(buttonHandle);
+		gtk_widget_get_preferred_size (buttonHandle, requisition);
+		if (hideHeader) {
 			GTK.gtk_widget_hide(buttonHandle);
-		} else {
-			gtk_widget_get_preferred_size (buttonHandle, requisition);
 		}
 		width = requisition.width;
 	}
@@ -604,10 +603,10 @@ public void setImage (Image image) {
 		int imageIndex = headerImageList.indexOf (image);
 		if (imageIndex == -1) imageIndex = headerImageList.add (image);
 		long /*int*/ pixbuf = headerImageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf (imageHandle, pixbuf);
+		gtk_image_set_from_gicon (imageHandle, pixbuf);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
-		gtk_image_set_from_pixbuf (imageHandle, 0);
+		gtk_image_set_from_gicon (imageHandle, 0);
 		GTK.gtk_widget_hide (imageHandle);
 	}
 }
