@@ -139,7 +139,6 @@ public void addSelectionListener (SelectionListener listener) {
 }
 
 void configure () {
-	long /*int*/ screen = GDK.gdk_screen_get_default ();
 	GTK.gtk_widget_realize (handle);
 	/*
 	 * Feature in GTK: using gdk_screen_get_monitor_at_window() does not accurately get the correct monitor on the machine.
@@ -147,10 +146,20 @@ void configure () {
 	 * the coordinates for where the tooltip should appear on the host.
 	 */
 	Point point = getLocation();
-	boolean multipleMonitors = (GDK.gdk_screen_get_n_monitors(screen) > 1) ? true : false;
-	int monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
+	boolean multipleMonitors;
+	int monitorNumber;
 	GdkRectangle dest = new GdkRectangle ();
-	GDK.gdk_screen_get_monitor_geometry (screen, monitorNumber, dest);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		long /*int*/ display = GDK.gdk_display_get_default();
+		multipleMonitors = GDK.gdk_display_get_n_monitors(display) > 1;
+		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, point.x, point.y);
+		GDK.gdk_monitor_get_geometry (monitor, dest);
+	} else {
+		long /*int*/ screen = GDK.gdk_screen_get_default ();
+		multipleMonitors = GDK.gdk_screen_get_n_monitors(screen) > 1;
+		monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
+		GDK.gdk_screen_get_monitor_geometry(screen, monitorNumber, dest);
+	}
 	point = getSize (dest.width / 4);
 	int w = point.x;
 	int h = point.y;
@@ -159,8 +168,10 @@ void configure () {
 	int y = point.y;
 	GTK.gtk_window_resize (handle, w, h + TIP_HEIGHT);
 	int[] polyline;
+	Rectangle bounds = display.getBounds();
+	int width = bounds != null ? bounds.width : GDK.gdk_screen_width();
 	spikeAbove = dest.height >= y + h + TIP_HEIGHT;
-	if ((dest.width >= x + w) || (multipleMonitors && GDK.gdk_screen_width() >= x + w)) {
+	if ((dest.width >= x + w) || (multipleMonitors && width >= x + w)) {
 		if (dest.height >= y + h + TIP_HEIGHT) {
 			int t = TIP_HEIGHT;
 			polyline = new int[] {
@@ -263,12 +274,7 @@ void configure () {
 	GTK.gtk_widget_realize(handle);
 	Region region = new Region (display);
 	region.add(DPIUtil.autoScaleDown(polyline));
-	if (GTK.GTK3) {
-		GTK.gtk_widget_shape_combine_region (handle, region.handle);
-	} else {
-		long /*int*/ window = gtk_widget_get_window (handle);
-		GDK.gdk_window_shape_combine_region (window, region.handle, 0, 0);
-	 }
+	GTK.gtk_widget_shape_combine_region (handle, region.handle);
 	region.dispose ();
 }
 
@@ -278,16 +284,12 @@ void createHandle (int index) {
 		state |= HANDLE;
 		handle = GTK.gtk_window_new (GTK.GTK_WINDOW_POPUP);
 		Color background = display.getSystemColor (SWT.COLOR_INFO_BACKGROUND);
-		if (GTK.GTK3) {
-			long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
-			GdkRGBA bgRGBA = background.handleRGBA;
-			String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "window" : "GtkWindow";
-			String css = name + " {background-color: " + display.gtk_rgba_to_css_string(bgRGBA) + ";}";
-			gtk_css_provider_load_from_css (context, css);
-			GTK.gtk_style_context_invalidate (context);
-		} else {
-			GTK.gtk_widget_modify_bg (handle, GTK.GTK_STATE_NORMAL, background.handle);
-		}
+		long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+		GdkRGBA bgRGBA = background.handle;
+		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "window" : "GtkWindow";
+		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(bgRGBA) + ";}";
+		gtk_css_provider_load_from_css (context, css);
+		GTK.gtk_style_context_invalidate (context);
 		GTK.gtk_window_set_type_hint (handle, GDK.GDK_WINDOW_TYPE_HINT_TOOLTIP);
 	}
 }
@@ -478,10 +480,22 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 void drawTooltip (long /*int*/ cr) {
-	long /*int*/ window = gtk_widget_get_window (handle);
+	long /*int*/ gdkResource = GTK.GTK4 ? gtk_widget_get_surface(handle) : gtk_widget_get_window (handle);
 	int x = BORDER + PADDING;
 	int y = BORDER + PADDING;
-	long /*int*/ cairo = cr != 0 ? cr : GDK.gdk_cairo_create(window);
+	long /*int*/ cairo = 0;
+	long /*int*/ context = 0;
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		if (cr == 0) {
+			long /*int*/ cairo_region = GDK.gdk_window_get_visible_region(gdkResource);
+			context = GDK.gdk_window_begin_draw_frame(gdkResource, cairo_region);
+			cairo = GDK.gdk_drawing_context_get_cairo_context(context);
+		} else {
+			cairo = cr;
+		}
+	} else {
+		cairo = cr != 0 ? cr : GDK.gdk_cairo_create(gdkResource);
+	}
 	if (cairo == 0) error (SWT.ERROR_NO_HANDLES);
 	int count = borderPolygon.length / 2;
 	if (count != 0) {
@@ -512,11 +526,7 @@ void drawTooltip (long /*int*/ cr) {
 		x += INSET;
 		int [] w = new int [1], h = new int [1];
 		Color foreground = display.getSystemColor (SWT.COLOR_INFO_FOREGROUND);
-		if (GTK.GTK3) {
-			GDK.gdk_cairo_set_source_rgba(cairo,foreground.handleRGBA);
-		} else {
-			GDK.gdk_cairo_set_source_color(cairo,foreground.handle);
-		}
+		GDK.gdk_cairo_set_source_rgba(cairo,foreground.handle);
 		Cairo.cairo_move_to(cairo, x,y );
 		OS.pango_cairo_show_layout(cairo, layoutText);
 		OS.pango_layout_get_pixel_size (layoutText, w, h);
@@ -525,15 +535,15 @@ void drawTooltip (long /*int*/ cr) {
 	if (layoutMessage != 0) {
 		x = BORDER + PADDING + INSET;
 		Color foreground = display.getSystemColor (SWT.COLOR_INFO_FOREGROUND);
-		if (GTK.GTK3) {
-			GDK.gdk_cairo_set_source_rgba(cairo,foreground.handleRGBA);
-		} else {
-			GDK.gdk_cairo_set_source_color(cairo,foreground.handle);
-		}
+		GDK.gdk_cairo_set_source_rgba(cairo,foreground.handle);
 		Cairo.cairo_move_to(cairo, x, y);
 		OS.pango_cairo_show_layout(cairo, layoutMessage);
 	}
-	if (cairo != cr) Cairo.cairo_destroy(cairo);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		if (cairo != cr && context != 0) GDK.gdk_window_end_draw_frame(gdkResource, context);
+	} else {
+		if (cairo != cr) Cairo.cairo_destroy(cairo);
+	}
 }
 
 @Override
@@ -543,23 +553,22 @@ long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
 	return 0;
 }
 
-@Override
-long /*int*/ gtk_expose_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	if ((state & OBSCURED) != 0) return 0;
-	drawTooltip (0);
-	return 0;
-}
-
 @Override
 long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
 	Point point = getLocation ();
 	int x = point.x;
 	int y = point.y;
-	long /*int*/ screen = GDK.gdk_screen_get_default ();
 	GTK.gtk_widget_realize (widget);
-	int monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
 	GdkRectangle dest = new GdkRectangle ();
-	GDK.gdk_screen_get_monitor_geometry (screen, monitorNumber, dest);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+		long /*int*/ display = GDK.gdk_display_get_default();
+		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, x, y);
+		GDK.gdk_monitor_get_geometry(monitor, dest);
+	} else {
+		long /*int*/ screen = GDK.gdk_screen_get_default ();
+		int monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
+		GDK.gdk_screen_get_monitor_geometry (screen, monitorNumber, dest);
+	}
 	GtkAllocation widgetAllocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (widget, widgetAllocation);
 	int w = widgetAllocation.width;
