@@ -497,11 +497,11 @@ void setIMEFont () {
 	long /*int*/ hIMC = OS.ImmGetContext (hwnd);
 	/* Save the current IME font */
 	if (oldFont == null) {
-		oldFont = OS.IsUnicode ? (LOGFONT) new LOGFONTW () : new LOGFONTA ();
+		oldFont = new LOGFONT ();
 		if (!OS.ImmGetCompositionFont (hIMC, oldFont)) oldFont = null;
 	}
 	/* Set new IME font */
-	LOGFONT logFont = OS.IsUnicode ? (LOGFONT) new LOGFONTW () : new LOGFONTA ();
+	LOGFONT logFont = new LOGFONT ();
 	if (OS.GetObject (hFont, LOGFONT.sizeof, logFont) != 0) {
 		OS.ImmSetCompositionFont (hIMC, logFont);
 	}
