@@ -87,7 +87,7 @@ public class DateTime extends Composite {
 		lpWndClass.hInstance = OS.GetModuleHandle (null);
 		lpWndClass.style &= ~OS.CS_GLOBALCLASS;
 		lpWndClass.style |= OS.CS_DBLCLKS;
-		OS.RegisterClass (lpWndClass);
+		OS.RegisterClass (DateTimeClass, lpWndClass);
 	}
 	static {
 		WNDCLASS lpWndClass = new WNDCLASS ();
@@ -110,10 +110,10 @@ public class DateTime extends Composite {
 		* code, other than SWT, could create a control with
 		* this class name, and fail unexpectedly.
 		*/
-		lpWndClass.hInstance = OS.GetModuleHandle (null);
+		lpWndClass.hInstance = OS.GetModuleHandle (null);;
 		lpWndClass.style &= ~OS.CS_GLOBALCLASS;
 		lpWndClass.style |= OS.CS_DBLCLKS;
-		OS.RegisterClass (lpWndClass);
+		OS.RegisterClass (CalendarClass, lpWndClass);
 	}
 	static final char SINGLE_QUOTE = '\''; //$NON-NLS-1$ short date format may include quoted text
 	static final char DAY_FORMAT_CONSTANT = 'd'; //$NON-NLS-1$ 1-4 lowercase 'd's represent day
