@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -145,10 +145,10 @@ static int checkStyle (int style) {
 				if (hFont != 0) {
 					hCurrentFont = hFont;
 				} else {
-					NONCLIENTMETRICS info = OS.IsUnicode ? (NONCLIENTMETRICS) new NONCLIENTMETRICSW () : new NONCLIENTMETRICSA ();
+					NONCLIENTMETRICS info = new NONCLIENTMETRICS ();
 					info.cbSize = NONCLIENTMETRICS.sizeof;
 					if (OS.SystemParametersInfo (OS.SPI_GETNONCLIENTMETRICS, 0, info, 0)) {
-						LOGFONT logFont = OS.IsUnicode ? (LOGFONT) ((NONCLIENTMETRICSW)info).lfCaptionFont : ((NONCLIENTMETRICSA)info).lfCaptionFont;
+						LOGFONT logFont = info.lfCaptionFont;
 						hCurrentFont = OS.CreateFontIndirect (logFont);
 					}
 				}
@@ -273,10 +273,10 @@ void drawWidget (GC gc, RECT clipRect) {
 		if (hFont != 0) {
 			hCurrentFont = hFont;
 		} else {
-			NONCLIENTMETRICS info = OS.IsUnicode ? (NONCLIENTMETRICS) new NONCLIENTMETRICSW () : new NONCLIENTMETRICSA ();
+			NONCLIENTMETRICS info = new NONCLIENTMETRICS ();
 			info.cbSize = NONCLIENTMETRICS.sizeof;
 			if (OS.SystemParametersInfo (OS.SPI_GETNONCLIENTMETRICS, 0, info, 0)) {
-				LOGFONT logFont = OS.IsUnicode ? (LOGFONT) ((NONCLIENTMETRICSW)info).lfCaptionFont : ((NONCLIENTMETRICSA)info).lfCaptionFont;
+				LOGFONT logFont = info.lfCaptionFont;
 				hCurrentFont = OS.CreateFontIndirect (logFont);
 			}
 		}
@@ -314,7 +314,7 @@ Control findThemeControl () {
 int getBandHeight () {
 	long /*int*/ hDC = OS.GetDC (handle);
 	long /*int*/ oldHFont = OS.SelectObject (hDC, hFont == 0 ? defaultFont () : hFont);
-	TEXTMETRIC lptm = OS.IsUnicode ? (TEXTMETRIC)new TEXTMETRICW() : new TEXTMETRICA();
+	TEXTMETRIC lptm = new TEXTMETRIC ();
 	OS.GetTextMetrics (hDC, lptm);
 	OS.SelectObject (hDC, oldHFont);
 	OS.ReleaseDC (handle, hDC);
@@ -552,7 +552,7 @@ void setScrollbar () {
 }
 
 /**
- * Sets the receiver's spacing. Spacing specifies the number of pixels allocated around
+ * Sets the receiver's spacing. Spacing specifies the number of points allocated around
  * each item.
  *
  * @param spacing the spacing around each item
