@@ -70,7 +70,7 @@ public class Scale extends Control {
 		lpWndClass.hInstance = OS.GetModuleHandle (null);
 		lpWndClass.style &= ~OS.CS_GLOBALCLASS;
 		lpWndClass.style |= OS.CS_DBLCLKS;
-		OS.RegisterClass (lpWndClass);
+		OS.RegisterClass (TrackBarClass, lpWndClass);
 	}
 
 /**
