@@ -712,6 +712,16 @@ void destroyToolTip (ToolTip toolTip) {
 void destroyWidget () {
 	fixActiveShell ();
 	super.destroyWidget ();
+
+	/*
+	* Destroy context only after the controls that used it were destroyed.
+	* Technically, that shouldn't be necessary, because 'Control.releaseWidget'
+	* clears up association by calling 'OS.ImmAssociateContext (handle, 0)'.
+	* However, there's a bug in Windows 10 (see bug 526758), and this is the workaround.
+	*/
+	if (OS.IsDBLocale) {
+		if (hIMC != 0) OS.ImmDestroyContext (hIMC);
+	}
 }
 
 @Override
@@ -1366,9 +1376,6 @@ void releaseWidget () {
 	}
 	lpstrTip = 0;
 	toolTipHandle = balloonTipHandle = menuItemToolTipHandle = 0;
-	if (OS.IsDBLocale) {
-		if (hIMC != 0) OS.ImmDestroyContext (hIMC);
-	}
 	lastActive = null;
 	toolTitle = balloonTitle = null;
 }
@@ -1845,22 +1852,6 @@ void setToolTipText (long /*int*/ hwnd, String text) {
 	}
 }
 
-void setToolTipText (NMTTDISPINFO lpnmtdi, byte [] buffer) {
-	/*
-	* Ensure that the current position of the mouse
-	* is inside the client area of the shell.  This
-	* prevents tool tips from popping up over the
-	* shell trimmings.
-	*/
-	if (!hasCursor ()) return;
-	long /*int*/ hHeap = OS.GetProcessHeap ();
-	if (lpstrTip != 0) OS.HeapFree (hHeap, 0, lpstrTip);
-	int byteCount = buffer.length;
-	lpstrTip = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
-	OS.MoveMemory (lpstrTip, buffer, byteCount);
-	lpnmtdi.lpszText = lpstrTip;
-}
-
 void setToolTipText (NMTTDISPINFO lpnmtdi, char [] buffer) {
 	/*
 	* Ensure that the current position of the mouse
