@@ -641,7 +641,7 @@ public void clearSelection () {
 		long /*int*/ hDC = OS.GetDC (handle);
 		newFont = OS.SendMessage (handle, OS.WM_GETFONT, 0, 0);
 		if (newFont != 0) oldFont = OS.SelectObject (hDC, newFont);
-		TEXTMETRIC tm = OS.IsUnicode ? (TEXTMETRIC) new TEXTMETRICW () : new TEXTMETRICA ();
+		TEXTMETRIC tm = new TEXTMETRIC ();
 		OS.GetTextMetrics (hDC, tm);
 		int count = (style & SWT.SINGLE) != 0 ? 1 : (int)/*64*/OS.SendMessage (handle, OS.EM_GETLINECOUNT, 0, 0);
 		height = count * tm.tmHeight;
@@ -1128,7 +1128,7 @@ int getLineHeightInPixels () {
 	long /*int*/ hDC = OS.GetDC (handle);
 	newFont = OS.SendMessage (handle, OS.WM_GETFONT, 0, 0);
 	if (newFont != 0) oldFont = OS.SelectObject (hDC, newFont);
-	TEXTMETRIC tm = OS.IsUnicode ? (TEXTMETRIC) new TEXTMETRICW () : new TEXTMETRICA ();
+	TEXTMETRIC tm = new TEXTMETRIC ();
 	OS.GetTextMetrics (hDC, tm);
 	if (newFont != 0) OS.SelectObject (hDC, oldFont);
 	OS.ReleaseDC (handle, hDC);
@@ -1443,19 +1443,19 @@ public int getTopIndex () {
 }
 
 /**
- * Returns the top pixel.
+ * Returns the top SWT logical point.
  * <p>
- * The top pixel is the pixel position of the line
+ * The top point is the SWT logical point position of the line
  * that is currently at the top of the widget.  On
  * some platforms, a text widget can be scrolled by
- * pixels instead of lines so that a partial line
+ * points instead of lines so that a partial line
  * is displayed at the top of the widget.
  * </p><p>
- * The top pixel changes when the widget is scrolled.
- * The top pixel does not include the widget trimming.
+ * The top SWT logical point changes when the widget is scrolled.
+ * The top SWT logical point does not include the widget trimming.
  * </p>
  *
- * @return the pixel position of the top line
+ * @return the SWT logical point position of the top line
  *
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
@@ -1839,7 +1839,7 @@ void setBoundsInPixels (int x, int y, int width, int height, int flags) {
 			long /*int*/ hDC = OS.GetDC (handle);
 			newFont = OS.SendMessage (handle, OS.WM_GETFONT, 0, 0);
 			if (newFont != 0) oldFont = OS.SelectObject (hDC, newFont);
-			TEXTMETRIC tm = OS.IsUnicode ? (TEXTMETRIC) new TEXTMETRICW () : new TEXTMETRICA ();
+			TEXTMETRIC tm = new TEXTMETRIC ();
 			OS.GetTextMetrics (hDC, tm);
 			if (newFont != 0) OS.SelectObject (hDC, oldFont);
 			OS.ReleaseDC (handle, hDC);
