@@ -14,6 +14,7 @@
  */
 package org.eclipse.swt.tests.gtk;
 
+import org.junit.runner.JUnitCore;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
@@ -21,12 +22,13 @@ import org.junit.runners.Suite;
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
 		// Test.class be added here.
+	Test_GtkConverter.class
 })
 
 public class AllGTKTests {
 
 	public static void main(String[] args) {
-//		JUnitCore.main(AllGTKTests.class.getName()); // Enable once a test is added.
+		JUnitCore.main(AllGTKTests.class.getName()); // Enable once a test is added.
 	}
 
 }
