@@ -525,7 +525,7 @@ public void test_isFocusControl() {
 }
 @Test
 public void test_isReparentable() {
-	assertEquals ("isReparentable", control.isReparentable(), SwtTestUtil.isReparentablePlatform());
+	assertTrue ("isReparentable", control.isReparentable());
 }
 @Test
 public void test_isVisible() {
@@ -535,13 +535,11 @@ public void test_isVisible() {
 	control.setVisible(false);
 	assertFalse(control.isVisible());
 
-	if (!SwtTestUtil.isAIX) {
-		control.setVisible(true);
-		shell.setVisible(true);
-		assertTrue("Window should be visible", control.isVisible());
-		shell.setVisible(false);
-		assertFalse("Window should not be visible", control.isVisible());
-	}
+	control.setVisible(true);
+	shell.setVisible(true);
+	assertTrue("Window should be visible", control.isVisible());
+	shell.setVisible(false);
+	assertFalse("Window should not be visible", control.isVisible());
 }
 @Test
 public void test_moveAboveLorg_eclipse_swt_widgets_Control() {
@@ -630,6 +628,17 @@ public void test_setBackgroundAlphaLorg_eclipse_swt_graphics_Color() {
 	fg.dispose();
 }
 @Test
+public void test_setBackgroundDisposedColorLorg_eclipse_swt_graphics_Color() {
+	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	color.dispose();
+	try {
+		control.setBackground(color);
+		fail("setting a disposed color object with Control.setBackground(Color) should throw an exception");
+	} catch (IllegalArgumentException e) {
+		// expected, since the color is disposed
+	}
+}
+@Test
 public void test_setBoundsIIII() {
 	control.setBounds(10, 20, 30, 40);
 	assertEquals(new Rectangle(10, 20, 30, 40), control.getBounds());
@@ -745,7 +754,7 @@ public void test_setForegroundLorg_eclipse_swt_graphics_Color() {
 @Test
 public void test_setForegroundAlphaLorg_eclipse_swt_graphics_Color() {
 	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
-			SwtTestUtil.isCocoa || SwtTestUtil.isGTK3());
+			SwtTestUtil.isCocoa || SwtTestUtil.isGTK);
 	Color color = new Color (control.getDisplay(), 255, 0, 0, 0);
 	control.setForeground(color);
 	assertEquals(color, control.getForeground());
@@ -756,6 +765,17 @@ public void test_setForegroundAlphaLorg_eclipse_swt_graphics_Color() {
 	bg.dispose();
 }
 
+@Test
+public void test_setForegroundDisposedColorLorg_eclipse_swt_graphics_Color() {
+	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	color.dispose();
+	try {
+		control.setForeground(color);
+		fail("setting a disposed color object with Control.setForeground(Color) should throw an exception");
+	} catch (IllegalArgumentException e) {
+		// expected, since the color is disposed
+	}
+}
 @Test
 public void test_setLayoutDataLjava_lang_Object() {
 	control.setLayoutData(this);
