@@ -667,6 +667,29 @@ public void test_setBoundsLorg_eclipse_swt_graphics_Rectangle() {
 //	}
 }
 
+/**
+ * Regression test for Bug 436841 - [GTK3] FocusOut/In and Activate/Deactivate
+ * events when opening context menu. Only applicable on GTK x11.
+ */
+@Test
+public void test_activateEventSend() {
+	if (SwtTestUtil.isGTK && SwtTestUtil.isX11) {
+		Shell testShell = new Shell(shell, SWT.SHELL_TRIM);
+		testShell.addListener(SWT.Activate, e -> {
+			listenerCalled = true;
+			});
+		testShell.open();
+		int[] styles = {SWT.ON_TOP, SWT.APPLICATION_MODAL, SWT.PRIMARY_MODAL, SWT.SYSTEM_MODAL, SWT.NO_TRIM, SWT.BORDER, SWT.SHELL_TRIM};
+		for (int i = 0; i < styles.length; i++) {
+			Shell childShell = new Shell(testShell, styles[i]);
+			listenerCalled = false;
+			childShell.open();
+			childShell.dispose();
+			assertTrue(listenerCalled);
+		}
+	}
+}
+
 /**
  * Regression test for Bug 445900: [GTK] Shell#computeTrim(..) wrong for
  * first invisible shell (editor hovers jump when enriched)
